"""
Python module generated from Java source file org.bukkit.util.noise.OctaveGenerator

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.util.noise import *
from typing import Any, Callable, Iterable, Tuple


class OctaveGenerator:
    """
    Creates noise using unbiased octaves
    """

    def setScale(self, scale: float) -> None:
        """
        Sets the scale used for all coordinates passed to this generator.
        
        This is the equivalent to setting each coordinate to the specified
        value.

        Arguments
        - scale: New value to scale each coordinate by
        """
        ...


    def getXScale(self) -> float:
        """
        Gets the scale used for each X-coordinates passed

        Returns
        - X scale
        """
        ...


    def setXScale(self, scale: float) -> None:
        """
        Sets the scale used for each X-coordinates passed

        Arguments
        - scale: New X scale
        """
        ...


    def getYScale(self) -> float:
        """
        Gets the scale used for each Y-coordinates passed

        Returns
        - Y scale
        """
        ...


    def setYScale(self, scale: float) -> None:
        """
        Sets the scale used for each Y-coordinates passed

        Arguments
        - scale: New Y scale
        """
        ...


    def getZScale(self) -> float:
        """
        Gets the scale used for each Z-coordinates passed

        Returns
        - Z scale
        """
        ...


    def setZScale(self, scale: float) -> None:
        """
        Sets the scale used for each Z-coordinates passed

        Arguments
        - scale: New Z scale
        """
        ...


    def getOctaves(self) -> list["NoiseGenerator"]:
        """
        Gets a clone of the individual octaves used within this generator

        Returns
        - Clone of the individual octaves
        """
        ...


    def noise(self, x: float, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 1D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, frequency: float, amplitude: float, normalized: bool) -> float:
        """
        Generates noise for the 1D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave
        - normalized: If True, normalize the value to [-1, 1]

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 2D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, frequency: float, amplitude: float, normalized: bool) -> float:
        """
        Generates noise for the 2D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave
        - normalized: If True, normalize the value to [-1, 1]

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, z: float, frequency: float, amplitude: float) -> float:
        """
        Generates noise for the 3D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - z: Z-coordinate
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave

        Returns
        - Resulting noise
        """
        ...


    def noise(self, x: float, y: float, z: float, frequency: float, amplitude: float, normalized: bool) -> float:
        """
        Generates noise for the 3D coordinates using the specified number of
        octaves and parameters

        Arguments
        - x: X-coordinate
        - y: Y-coordinate
        - z: Z-coordinate
        - frequency: How much to alter the frequency by each octave
        - amplitude: How much to alter the amplitude by each octave
        - normalized: If True, normalize the value to [-1, 1]

        Returns
        - Resulting noise
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Tripwire

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import Attachable
from org.bukkit.block.data import MultipleFacing
from org.bukkit.block.data import Powerable
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Tripwire(Attachable, MultipleFacing, Powerable):
    """
    'disarmed' denotes that the tripwire was broken with shears and will not
    subsequently produce a current when destroyed.
    """

    def isDisarmed(self) -> bool:
        """
        Gets the value of the 'disarmed' property.

        Returns
        - the 'disarmed' value
        """
        ...


    def setDisarmed(self, disarmed: bool) -> None:
        """
        Sets the value of the 'disarmed' property.

        Arguments
        - disarmed: the new 'disarmed' value
        """
        ...



"""
Python module generated from Java source file org.joml.FrustumRayBuilder

Java source file obtained from artifact joml version 1.10.8

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.joml import *
from typing import Any, Callable, Iterable, Tuple


class FrustumRayBuilder:
    """
    Provides methods to compute rays through an arbitrary perspective transformation defined by a Matrix4fc.
    
    This can be used to compute the eye-rays in simple software-based raycasting/raytracing.
    
    To obtain the origin of the rays call .origin(Vector3f).
    Then to compute the directions of subsequent rays use .dir(float, float, Vector3f).

    Author(s)
    - Kai Burjack
    """

    def __init__(self):
        """
        Create a new FrustumRayBuilder with an undefined frustum.
        
        Before obtaining ray directions, make sure to define the frustum using .set(Matrix4fc).
        """
        ...


    def __init__(self, m: "Matrix4fc"):
        """
        Create a new FrustumRayBuilder from the given Matrix4fc matrix by extracing the matrix's frustum.

        Arguments
        - m: the Matrix4fc to create the frustum from
        """
        ...


    def set(self, m: "Matrix4fc") -> "FrustumRayBuilder":
        """
        Update the stored frustum corner rays and origin of `this` FrustumRayBuilder with the given Matrix4fc matrix.
        
        Reference: <a href="http://gamedevs.org/uploads/fast-extraction-viewing-frustum-planes-from-world-view-projection-matrix.pdf">
        Fast Extraction of Viewing Frustum Planes from the World-View-Projection Matrix</a>
        
        Reference: <a href="http://geomalgorithms.com/a05-_intersect-1.html">http://geomalgorithms.com</a>

        Arguments
        - m: the Matrix4fc matrix to update the frustum corner rays and origin with

        Returns
        - this
        """
        ...


    def origin(self, origin: "Vector3f") -> "Vector3fc":
        """
        Store the eye/origin of the perspective frustum in the given `origin`.

        Arguments
        - origin: will hold the perspective origin

        Returns
        - the `origin` vector
        """
        ...


    def dir(self, x: float, y: float, dir: "Vector3f") -> "Vector3fc":
        """
        Obtain the normalized direction of a ray starting at the center of the coordinate system and going 
        through the near frustum plane.
        
        The parameters `x` and `y` are used to interpolate the generated ray direction
        from the bottom-left to the top-right frustum corners.

        Arguments
        - x: the interpolation factor along the left-to-right frustum planes, within `[0..1]`
        - y: the interpolation factor along the bottom-to-top frustum planes, within `[0..1]`
        - dir: will hold the normalized ray direction

        Returns
        - the `dir` vector
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.introspector.GenericProperty

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.reflect import Array
from java.lang.reflect import GenericArrayType
from java.lang.reflect import ParameterizedType
from java.lang.reflect import Type
from org.yaml.snakeyaml.introspector import *
from typing import Any, Callable, Iterable, Tuple


class GenericProperty(Property):
    """
    Shared code for all the properties
    """

    def __init__(self, name: str, aClass: type[Any], aType: "Type"):
        ...


    def getActualTypeArguments(self) -> list[type[Any]]:
        ...



"""
Python module generated from Java source file org.bukkit.inventory.JukeboxInventory

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Jukebox
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class JukeboxInventory(Inventory):
    """
    Interface to the inventory of a Jukebox.
    """

    def setRecord(self, item: "ItemStack") -> None:
        """
        Set the record in the jukebox.
        
        This will immediately start playing the inserted item or stop playing if the
        item provided is null.

        Arguments
        - item: the new record
        """
        ...


    def getRecord(self) -> "ItemStack":
        """
        Get the record in the jukebox.

        Returns
        - the current record
        """
        ...


    def getHolder(self) -> "Jukebox":
        ...



"""
Python module generated from Java source file com.google.common.collect.ImmutableSortedAsList

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.util import Comparator
from java.util import Spliterator
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ImmutableSortedAsList(RegularImmutableAsList, SortedIterable):
    """
    List returned by `ImmutableSortedSet.asList()` when the set isn't empty.

    Author(s)
    - Louis Wasserman
    """

    def comparator(self) -> "Comparator"["E"]:
        ...


    def indexOf(self, target: "Object") -> int:
        ...


    def lastIndexOf(self, target: "Object") -> int:
        ...


    def contains(self, target: "Object") -> bool:
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        ...



"""
Python module generated from Java source file com.google.common.collect.Iterables

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.base import Function
from com.google.common.base import Optional
from com.google.common.base import Predicate
from com.google.common.base import Predicates
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Comparator
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Queue
from java.util import RandomAccess
from java.util import Spliterator
from java.util.function import Consumer
from java.util.stream import Stream
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import NonNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Iterables:
    """
    An assortment of mainly legacy static utility methods that operate on or return objects of type
    `Iterable`. Except as noted, each method has a corresponding Iterator-based method
    in the Iterators class.
    
    **Java 8+ users:** several common uses for this class are now more comprehensively
    addressed by the new java.util.stream.Stream library. Read the method documentation below
    for comparisons. This class is not being deprecated, but we gently encourage you to migrate to
    streams.
    
    *Performance notes:* Unless otherwise noted, all of the iterables produced in this class
    are *lazy*, which means that their iterators only advance the backing iteration when
    absolutely necessary.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/CollectionUtilitiesExplained#iterables">`Iterables`</a>.

    Author(s)
    - Jared Levy

    Since
    - 2.0
    """

    @staticmethod
    def unmodifiableIterable(iterable: Iterable["T"]) -> Iterable["T"]:
        """
        Returns an unmodifiable view of `iterable`.
        """
        ...


    @staticmethod
    def unmodifiableIterable(iterable: "ImmutableCollection"["E"]) -> Iterable["E"]:
        """
        Simply returns its argument.

        Since
        - 10.0

        Deprecated
        - no need to use this
        """
        ...


    @staticmethod
    def size(iterable: Iterable[Any]) -> int:
        """
        Returns the number of elements in `iterable`.
        """
        ...


    @staticmethod
    def contains(iterable: Iterable["Object"], element: "Object") -> bool:
        ...


    @staticmethod
    def removeAll(removeFrom: Iterable[Any], elementsToRemove: Iterable[Any]) -> bool:
        """
        Removes, from an iterable, every element that belongs to the provided collection.
        
        This method calls Collection.removeAll if `iterable` is a collection, and
        Iterators.removeAll otherwise.

        Arguments
        - removeFrom: the iterable to (potentially) remove elements from
        - elementsToRemove: the elements to remove

        Returns
        - `True` if any element was removed from `iterable`
        """
        ...


    @staticmethod
    def retainAll(removeFrom: Iterable[Any], elementsToRetain: Iterable[Any]) -> bool:
        """
        Removes, from an iterable, every element that does not belong to the provided collection.
        
        This method calls Collection.retainAll if `iterable` is a collection, and
        Iterators.retainAll otherwise.

        Arguments
        - removeFrom: the iterable to (potentially) remove elements from
        - elementsToRetain: the elements to retain

        Returns
        - `True` if any element was removed from `iterable`
        """
        ...


    @staticmethod
    def removeIf(removeFrom: Iterable["T"], predicate: "Predicate"["T"]) -> bool:
        """
        Removes, from an iterable, every element that satisfies the provided predicate.
        
        Removals may or may not happen immediately as each element is tested against the predicate.
        The behavior of this method is not specified if `predicate` is dependent on `removeFrom`.
        
        **Java 8+ users:** if `removeFrom` is a Collection, use `removeFrom.removeIf(predicate)` instead.

        Arguments
        - removeFrom: the iterable to (potentially) remove elements from
        - predicate: a predicate that determines whether an element should be removed

        Returns
        - `True` if any elements were removed from the iterable

        Raises
        - UnsupportedOperationException: if the iterable does not support `remove()`.

        Since
        - 2.0
        """
        ...


    @staticmethod
    def elementsEqual(iterable1: Iterable[Any], iterable2: Iterable[Any]) -> bool:
        """
        Determines whether two iterables contain equal elements in the same order. More specifically,
        this method returns `True` if `iterable1` and `iterable2` contain the same
        number of elements and every element of `iterable1` is equal to the corresponding element
        of `iterable2`.
        """
        ...


    @staticmethod
    def toString(iterable: Iterable[Any]) -> str:
        """
        Returns a string representation of `iterable`, with the format `[e1, e2, ..., en]`
        (that is, identical to java.util.Arrays Arrays`.toString(Iterables.toArray(iterable))`). Note that for *most* implementations of Collection, `collection.toString()` also gives the same result, but that behavior is not
        generally guaranteed.
        """
        ...


    @staticmethod
    def getOnlyElement(iterable: Iterable["T"]) -> "T":
        """
        Returns the single element contained in `iterable`.
        
        **Java 8+ users:** the `Stream` equivalent to this method is `stream.collect(MoreCollectors.onlyElement())`.

        Raises
        - NoSuchElementException: if the iterable is empty
        - IllegalArgumentException: if the iterable contains multiple elements
        """
        ...


    @staticmethod
    def getOnlyElement(iterable: Iterable["T"], defaultValue: "T") -> "T":
        """
        Returns the single element contained in `iterable`, or `defaultValue` if the
        iterable is empty.
        
        **Java 8+ users:** the `Stream` equivalent to this method is `stream.collect(MoreCollectors.toOptional()).orElse(defaultValue)`.

        Raises
        - IllegalArgumentException: if the iterator contains multiple elements
        """
        ...


    @staticmethod
    def toArray(iterable: Iterable["T"], type: type["T"]) -> list["T"]:
        """
        Copies an iterable's elements into an array.

        Arguments
        - iterable: the iterable to copy
        - type: the type of the elements

        Returns
        - a newly-allocated array into which all the elements of the iterable have been copied
        """
        ...


    @staticmethod
    def addAll(addTo: Iterable["T"], elementsToAdd: Iterable["T"]) -> bool:
        """
        Adds all elements in `iterable` to `collection`.

        Returns
        - `True` if `collection` was modified as a result of this operation.
        """
        ...


    @staticmethod
    def frequency(iterable: Iterable[Any], element: "Object") -> int:
        """
        Returns the number of elements in the specified iterable that equal the specified object. This
        implementation avoids a full iteration when the iterable is a Multiset or Set.
        
        **Java 8+ users:** In most cases, the `Stream` equivalent of this method is `stream.filter(element::equals).count()`. If `element` might be null, use `stream.filter(Predicate.isEqual(element)).count()` instead.

        See
        - java.util.Collections.frequency(Collection, Object) Collections.frequency(Collection,
            Object)
        """
        ...


    @staticmethod
    def cycle(iterable: Iterable["T"]) -> Iterable["T"]:
        """
        Returns an iterable whose iterators cycle indefinitely over the elements of `iterable`.
        
        That iterator supports `remove()` if `iterable.iterator()` does. After `remove()` is called, subsequent cycles omit the removed element, which is no longer in `iterable`. The iterator's `hasNext()` method returns `True` until `iterable`
        is empty.
        
        **Warning:** Typical uses of the resulting iterator may produce an infinite loop. You
        should use an explicit `break` or be certain that you will eventually remove all the
        elements.
        
        To cycle over the iterable `n` times, use the following: `Iterables.concat(Collections.nCopies(n, iterable))`
        
        **Java 8+ users:** The `Stream` equivalent of this method is `Stream.generate(() -> iterable).flatMap(Streams::stream)`.
        """
        ...


    @staticmethod
    def cycle(*elements: Tuple["T", ...]) -> Iterable["T"]:
        """
        Returns an iterable whose iterators cycle indefinitely over the provided elements.
        
        After `remove` is invoked on a generated iterator, the removed element will no longer
        appear in either that iterator or any other iterator created from the same source iterable.
        That is, this method behaves exactly as `Iterables.cycle(Lists.newArrayList(elements))`.
        The iterator's `hasNext` method returns `True` until all of the original elements
        have been removed.
        
        **Warning:** Typical uses of the resulting iterator may produce an infinite loop. You
        should use an explicit `break` or be certain that you will eventually remove all the
        elements.
        
        To cycle over the elements `n` times, use the following: `Iterables.concat(Collections.nCopies(n, Arrays.asList(elements)))`
        
        **Java 8+ users:** If passing a single element `e`, the `Stream` equivalent
        of this method is `Stream.generate(() -> e)`. Otherwise, put the elements in a collection
        and use `Stream.generate(() -> collection).flatMap(Collection::stream)`.
        """
        ...


    @staticmethod
    def concat(a: Iterable["T"], b: Iterable["T"]) -> Iterable["T"]:
        """
        Combines two iterables into a single iterable. The returned iterable has an iterator that
        traverses the elements in `a`, followed by the elements in `b`. The source
        iterators are not polled until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it.
        
        **Java 8+ users:** The `Stream` equivalent of this method is `Stream.concat(a, b)`.
        """
        ...


    @staticmethod
    def concat(a: Iterable["T"], b: Iterable["T"], c: Iterable["T"]) -> Iterable["T"]:
        """
        Combines three iterables into a single iterable. The returned iterable has an iterator that
        traverses the elements in `a`, followed by the elements in `b`, followed by the
        elements in `c`. The source iterators are not polled until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it.
        
        **Java 8+ users:** The `Stream` equivalent of this method is `Streams.concat(a, b, c)`.
        """
        ...


    @staticmethod
    def concat(a: Iterable["T"], b: Iterable["T"], c: Iterable["T"], d: Iterable["T"]) -> Iterable["T"]:
        """
        Combines four iterables into a single iterable. The returned iterable has an iterator that
        traverses the elements in `a`, followed by the elements in `b`, followed by the
        elements in `c`, followed by the elements in `d`. The source iterators are not
        polled until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it.
        
        **Java 8+ users:** The `Stream` equivalent of this method is `Streams.concat(a, b, c, d)`.
        """
        ...


    @staticmethod
    def concat(*inputs: Tuple[Iterable["T"], ...]) -> Iterable["T"]:
        """
        Combines multiple iterables into a single iterable. The returned iterable has an iterator that
        traverses the elements of each iterable in `inputs`. The input iterators are not polled
        until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it.
        
        **Java 8+ users:** The `Stream` equivalent of this method is `Streams.concat(...)`.

        Raises
        - NullPointerException: if any of the provided iterables is null
        """
        ...


    @staticmethod
    def concat(inputs: Iterable[Iterable["T"]]) -> Iterable["T"]:
        """
        Combines multiple iterables into a single iterable. The returned iterable has an iterator that
        traverses the elements of each iterable in `inputs`. The input iterators are not polled
        until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it. The methods of the returned iterable may throw `NullPointerException` if any of the input iterators is null.
        
        **Java 8+ users:** The `Stream` equivalent of this method is `streamOfStreams.flatMap(s -> s)`.
        """
        ...


    @staticmethod
    def partition(iterable: Iterable["T"], size: int) -> Iterable[list["T"]]:
        """
        Divides an iterable into unmodifiable sublists of the given size (the final iterable may be
        smaller). For example, partitioning an iterable containing `[a, b, c, d, e]` with a
        partition size of 3 yields `[[a, b, c], [d, e]]` -- an outer iterable containing two
        inner lists of three and two elements, all in the original order.
        
        Iterators returned by the returned iterable do not support the Iterator.remove()
        method. The returned lists implement RandomAccess, whether or not the input list does.
        
        **Note:** The current implementation eagerly allocates storage for `size` elements.
        As a consequence, passing values like `Integer.MAX_VALUE` can lead to OutOfMemoryError.
        
        **Note:** if `iterable` is a List, use Lists.partition(List, int)
        instead.

        Arguments
        - iterable: the iterable to return a partitioned view of
        - size: the desired size of each partition (the last may be smaller)

        Returns
        - an iterable of unmodifiable lists containing the elements of `iterable` divided
            into partitions

        Raises
        - IllegalArgumentException: if `size` is nonpositive
        """
        ...


    @staticmethod
    def paddedPartition(iterable: Iterable["T"], size: int) -> Iterable[list["T"]]:
        """
        Divides an iterable into unmodifiable sublists of the given size, padding the final iterable
        with null values if necessary. For example, partitioning an iterable containing `[a, b,
        c, d, e]` with a partition size of 3 yields `[[a, b, c], [d, e, null]]` -- an outer
        iterable containing two inner lists of three elements each, all in the original order.
        
        Iterators returned by the returned iterable do not support the Iterator.remove()
        method.

        Arguments
        - iterable: the iterable to return a partitioned view of
        - size: the desired size of each partition

        Returns
        - an iterable of unmodifiable lists containing the elements of `iterable` divided
            into partitions (the final iterable may have trailing null elements)

        Raises
        - IllegalArgumentException: if `size` is nonpositive
        """
        ...


    @staticmethod
    def filter(unfiltered: Iterable["T"], retainIfTrue: "Predicate"["T"]) -> Iterable["T"]:
        """
        Returns a view of `unfiltered` containing all elements that satisfy the input predicate
        `retainIfTrue`. The returned iterable's iterator does not support `remove()`.
        
        **`Stream` equivalent:** Stream.filter.
        """
        ...


    @staticmethod
    def filter(unfiltered: Iterable[Any], desiredType: type["T"]) -> Iterable["T"]:
        """
        Returns a view of `unfiltered` containing all elements that are of the type `desiredType`. The returned iterable's iterator does not support `remove()`.
        
        **`Stream` equivalent:** `stream.filter(type::isInstance).map(type::cast)`.
        This does perform a little more work than necessary, so another option is to insert an
        unchecked cast at some later point:
        
        ```
        `@SuppressWarnings("unchecked") // safe because of ::isInstance check
        ImmutableList<NewType> result =
            (ImmutableList) stream.filter(NewType.class::isInstance).collect(toImmutableList());`
        ```
        """
        ...


    @staticmethod
    def any(iterable: Iterable["T"], predicate: "Predicate"["T"]) -> bool:
        """
        Returns `True` if any element in `iterable` satisfies the predicate.
        
        **`Stream` equivalent:** Stream.anyMatch.
        """
        ...


    @staticmethod
    def all(iterable: Iterable["T"], predicate: "Predicate"["T"]) -> bool:
        """
        Returns `True` if every element in `iterable` satisfies the predicate. If `iterable` is empty, `True` is returned.
        
        **`Stream` equivalent:** Stream.allMatch.
        """
        ...


    @staticmethod
    def find(iterable: Iterable["T"], predicate: "Predicate"["T"]) -> "T":
        """
        Returns the first element in `iterable` that satisfies the given predicate; use this
        method only when such an element is known to exist. If it is possible that *no* element
        will match, use .tryFind or .find(Iterable, Predicate, Object) instead.
        
        **`Stream` equivalent:** `stream.filter(predicate).findFirst().get()`

        Raises
        - NoSuchElementException: if no element in `iterable` matches the given predicate
        """
        ...


    @staticmethod
    def find(iterable: Iterable["T"], predicate: "Predicate"["T"], defaultValue: "T") -> "T":
        ...


    @staticmethod
    def tryFind(iterable: Iterable["T"], predicate: "Predicate"["T"]) -> "Optional"["T"]:
        """
        Returns an Optional containing the first element in `iterable` that satisfies the
        given predicate, if such an element exists.
        
        **Warning:** avoid using a `predicate` that matches `null`. If `null`
        is matched in `iterable`, a NullPointerException will be thrown.
        
        **`Stream` equivalent:** `stream.filter(predicate).findFirst()`

        Since
        - 11.0
        """
        ...


    @staticmethod
    def indexOf(iterable: Iterable["T"], predicate: "Predicate"["T"]) -> int:
        """
        Returns the index in `iterable` of the first element that satisfies the provided `predicate`, or `-1` if the Iterable has no such elements.
        
        More formally, returns the lowest index `i` such that `predicate.apply(Iterables.get(iterable, i))` returns `True`, or `-1` if there is no
        such index.

        Since
        - 2.0
        """
        ...


    @staticmethod
    def transform(fromIterable: Iterable["F"], function: "Function"["F", "T"]) -> Iterable["T"]:
        """
        Returns a view containing the result of applying `function` to each element of `fromIterable`.
        
        The returned iterable's iterator supports `remove()` if `fromIterable`'s
        iterator does. After a successful `remove()` call, `fromIterable` no longer
        contains the corresponding element.
        
        If the input `Iterable` is known to be a `List` or other `Collection`,
        consider Lists.transform and Collections2.transform.
        
        **`Stream` equivalent:** Stream.map
        """
        ...


    @staticmethod
    def get(iterable: Iterable["T"], position: int) -> "T":
        """
        Returns the element at the specified position in an iterable.
        
        **`Stream` equivalent:** `stream.skip(position).findFirst().get()` (throws
        `NoSuchElementException` if out of bounds)

        Arguments
        - position: position of the element to return

        Returns
        - the element at the specified position in `iterable`

        Raises
        - IndexOutOfBoundsException: if `position` is negative or greater than or equal to
            the size of `iterable`
        """
        ...


    @staticmethod
    def get(iterable: Iterable["T"], position: int, defaultValue: "T") -> "T":
        """
        Returns the element at the specified position in an iterable or a default value otherwise.
        
        **`Stream` equivalent:** `stream.skip(position).findFirst().orElse(defaultValue)` (returns the default value if the index
        is out of bounds)

        Arguments
        - position: position of the element to return
        - defaultValue: the default value to return if `position` is greater than or equal to
            the size of the iterable

        Returns
        - the element at the specified position in `iterable` or `defaultValue` if
            `iterable` contains fewer than `position + 1` elements.

        Raises
        - IndexOutOfBoundsException: if `position` is negative

        Since
        - 4.0
        """
        ...


    @staticmethod
    def getFirst(iterable: Iterable["T"], defaultValue: "T") -> "T":
        """
        Returns the first element in `iterable` or `defaultValue` if the iterable is empty.
        The Iterators analog to this method is Iterators.getNext.
        
        If no default value is desired (and the caller instead wants a NoSuchElementException to be thrown), it is recommended that `iterable.iterator().next()` is used instead.
        
        To get the only element in a single-element `Iterable`, consider using .getOnlyElement(Iterable) or .getOnlyElement(Iterable, Object) instead.
        
        **`Stream` equivalent:** `stream.findFirst().orElse(defaultValue)`

        Arguments
        - defaultValue: the default value to return if the iterable is empty

        Returns
        - the first element of `iterable` or the default value

        Since
        - 7.0
        """
        ...


    @staticmethod
    def getLast(iterable: Iterable["T"]) -> "T":
        """
        Returns the last element of `iterable`. If `iterable` is a List with RandomAccess support, then this operation is guaranteed to be `O(1)`.
        
        **`Stream` equivalent:** Streams.findLast Streams.findLast(stream).get()

        Returns
        - the last element of `iterable`

        Raises
        - NoSuchElementException: if the iterable is empty
        """
        ...


    @staticmethod
    def getLast(iterable: Iterable["T"], defaultValue: "T") -> "T":
        """
        Returns the last element of `iterable` or `defaultValue` if the iterable is empty.
        If `iterable` is a List with RandomAccess support, then this operation is
        guaranteed to be `O(1)`.
        
        **`Stream` equivalent:** `Streams.findLast(stream).orElse(defaultValue)`

        Arguments
        - defaultValue: the value to return if `iterable` is empty

        Returns
        - the last element of `iterable` or the default value

        Since
        - 3.0
        """
        ...


    @staticmethod
    def skip(iterable: Iterable["T"], numberToSkip: int) -> Iterable["T"]:
        """
        Returns a view of `iterable` that skips its first `numberToSkip` elements. If
        `iterable` contains fewer than `numberToSkip` elements, the returned iterable skips
        all of its elements.
        
        Modifications to the underlying Iterable before a call to `iterator()` are
        reflected in the returned iterator. That is, the iterator skips the first `numberToSkip`
        elements that exist when the `Iterator` is created, not when `skip()` is called.
        
        The returned iterable's iterator supports `remove()` if the iterator of the underlying
        iterable supports it. Note that it is *not* possible to delete the last skipped element by
        immediately calling `remove()` on that iterator, as the `Iterator` contract states
        that a call to `remove()` before a call to `next()` will throw an IllegalStateException.
        
        **`Stream` equivalent:** Stream.skip

        Since
        - 3.0
        """
        ...


    @staticmethod
    def limit(iterable: Iterable["T"], limitSize: int) -> Iterable["T"]:
        """
        Returns a view of `iterable` containing its first `limitSize` elements. If `iterable` contains fewer than `limitSize` elements, the returned view contains all of its
        elements. The returned iterable's iterator supports `remove()` if `iterable`'s
        iterator does.
        
        **`Stream` equivalent:** Stream.limit

        Arguments
        - iterable: the iterable to limit
        - limitSize: the maximum number of elements in the returned iterable

        Raises
        - IllegalArgumentException: if `limitSize` is negative

        Since
        - 3.0
        """
        ...


    @staticmethod
    def consumingIterable(iterable: Iterable["T"]) -> Iterable["T"]:
        """
        Returns a view of the supplied iterable that wraps each generated Iterator through
        Iterators.consumingIterator(Iterator).
        
        Note: If `iterable` is a Queue, the returned iterable will instead use Queue.isEmpty and Queue.remove(), since Queue's iteration order is undefined.
        Calling Iterator.hasNext() on a generated iterator from the returned iterable may cause
        an item to be immediately dequeued for return on a subsequent call to Iterator.next().
        
        Whether the input `iterable` is a Queue or not, the returned `Iterable`
        is not thread-safe.

        Arguments
        - iterable: the iterable to wrap

        Returns
        - a view of the supplied iterable that wraps each generated iterator through Iterators.consumingIterator(Iterator); for queues, an iterable that generates iterators
            that return and consume the queue's elements in queue order

        See
        - Iterators.consumingIterator(Iterator)

        Since
        - 2.0
        """
        ...


    @staticmethod
    def isEmpty(iterable: Iterable[Any]) -> bool:
        """
        Determines if the given iterable contains no elements.
        
        There is no precise Iterator equivalent to this method, since one can only ask an
        iterator whether it has any elements *remaining* (which one does using Iterator.hasNext).
        
        **`Stream` equivalent:** `!stream.findAny().isPresent()`

        Returns
        - `True` if the iterable contains no elements
        """
        ...


    @staticmethod
    def mergeSorted(iterables: Iterable[Iterable["T"]], comparator: "Comparator"["T"]) -> Iterable["T"]:
        """
        Returns an iterable over the merged contents of all given `iterables`. Equivalent entries
        will not be de-duplicated.
        
        Callers must ensure that the source `iterables` are in non-descending order as this
        method does not sort its input.
        
        For any equivalent elements across all `iterables`, it is undefined which element is
        returned first.

        Since
        - 11.0
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.PriorityBlockingQueue

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.invoke import MethodHandles
from java.lang.invoke import VarHandle
from java.util import AbstractQueue
from java.util import Arrays
from java.util import Comparator
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Objects
from java.util import PriorityQueue
from java.util import Queue
from java.util import SortedSet
from java.util import Spliterator
from java.util.concurrent import *
from java.util.concurrent.locks import Condition
from java.util.concurrent.locks import ReentrantLock
from java.util.function import Consumer
from java.util.function import Predicate
from jdk.internal.access import SharedSecrets
from jdk.internal.util import ArraysSupport
from typing import Any, Callable, Iterable, Tuple


class PriorityBlockingQueue(AbstractQueue, BlockingQueue, Serializable):
    """
    An unbounded BlockingQueue blocking queue that uses
    the same ordering rules as class PriorityQueue and supplies
    blocking retrieval operations.  While this queue is logically
    unbounded, attempted additions may fail due to resource exhaustion
    (causing `OutOfMemoryError`). This class does not permit
    `null` elements.  A priority queue relying on Comparable natural ordering also does not permit insertion of
    non-comparable objects (doing so results in
    `ClassCastException`).
    
    This class and its iterator implement all of the *optional*
    methods of the Collection and Iterator interfaces.
    The Iterator provided in method .iterator() and the
    Spliterator provided in method .spliterator() are *not*
    guaranteed to traverse the elements of the PriorityBlockingQueue in
    any particular order. If you need ordered traversal, consider using
    `Arrays.sort(pq.toArray())`.  Also, method `drainTo` can
    be used to *remove* some or all elements in priority order and
    place them in another collection.
    
    Operations on this class make no guarantees about the ordering
    of elements with equal priority. If you need to enforce an
    ordering, you can define custom classes or comparators that use a
    secondary key to break ties in primary priority values.  For
    example, here is a class that applies first-in-first-out
    tie-breaking to comparable elements. To use it, you would insert a
    `new FIFOEntry(anEntry)` instead of a plain entry object.
    
    ``` `class FIFOEntry<E extends Comparable<? super E>>
        implements Comparable<FIFOEntry<E>> {
      static final AtomicLong seq = new AtomicLong();
      final long seqNum;
      final E entry;
      public FIFOEntry(E entry) {
        seqNum = seq.getAndIncrement();
        this.entry = entry;`
      public E getEntry() { return entry; }
      public int compareTo(FIFOEntry<E> other) {
        int res = entry.compareTo(other.entry);
        if (res == 0 && other.entry != this.entry)
          res = (seqNum < other.seqNum ? -1 : 1);
        return res;
      }
    }}```
    
    This class is a member of the
    <a href="/java.base/java/util/package-summary.html#CollectionsFramework">
    Java Collections Framework</a>.
    
    Type `<E>`: the type of elements held in this queue

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self):
        """
        Creates a `PriorityBlockingQueue` with the default
        initial capacity (11) that orders its elements according to
        their Comparable natural ordering.
        """
        ...


    def __init__(self, initialCapacity: int):
        """
        Creates a `PriorityBlockingQueue` with the specified
        initial capacity that orders its elements according to their
        Comparable natural ordering.

        Arguments
        - initialCapacity: the initial capacity for this priority queue

        Raises
        - IllegalArgumentException: if `initialCapacity` is less
                than 1
        """
        ...


    def __init__(self, initialCapacity: int, comparator: "Comparator"["E"]):
        """
        Creates a `PriorityBlockingQueue` with the specified initial
        capacity that orders its elements according to the specified
        comparator.

        Arguments
        - initialCapacity: the initial capacity for this priority queue
        - comparator: the comparator that will be used to order this
                priority queue.  If `null`, the Comparable
                natural ordering of the elements will be used.

        Raises
        - IllegalArgumentException: if `initialCapacity` is less
                than 1
        """
        ...


    def __init__(self, c: Iterable["E"]):
        """
        Creates a `PriorityBlockingQueue` containing the elements
        in the specified collection.  If the specified collection is a
        SortedSet or a PriorityBlockingQueue, this
        priority queue will be ordered according to the same ordering.
        Otherwise, this priority queue will be ordered according to the
        Comparable natural ordering of its elements.

        Arguments
        - c: the collection whose elements are to be placed
                into this priority queue

        Raises
        - ClassCastException: if elements of the specified collection
                cannot be compared to one another according to the priority
                queue's ordering
        - NullPointerException: if the specified collection or any
                of its elements are null
        """
        ...


    def add(self, e: "E") -> bool:
        """
        Inserts the specified element into this priority queue.

        Arguments
        - e: the element to add

        Returns
        - `True` (as specified by Collection.add)

        Raises
        - ClassCastException: if the specified element cannot be compared
                with elements currently in the priority queue according to the
                priority queue's ordering
        - NullPointerException: if the specified element is null
        """
        ...


    def offer(self, e: "E") -> bool:
        """
        Inserts the specified element into this priority queue.
        As the queue is unbounded, this method will never return `False`.

        Arguments
        - e: the element to add

        Returns
        - `True` (as specified by Queue.offer)

        Raises
        - ClassCastException: if the specified element cannot be compared
                with elements currently in the priority queue according to the
                priority queue's ordering
        - NullPointerException: if the specified element is null
        """
        ...


    def put(self, e: "E") -> None:
        """
        Inserts the specified element into this priority queue.
        As the queue is unbounded, this method will never block.

        Arguments
        - e: the element to add

        Raises
        - ClassCastException: if the specified element cannot be compared
                with elements currently in the priority queue according to the
                priority queue's ordering
        - NullPointerException: if the specified element is null
        """
        ...


    def offer(self, e: "E", timeout: int, unit: "TimeUnit") -> bool:
        """
        Inserts the specified element into this priority queue.
        As the queue is unbounded, this method will never block or
        return `False`.

        Arguments
        - e: the element to add
        - timeout: This parameter is ignored as the method never blocks
        - unit: This parameter is ignored as the method never blocks

        Returns
        - `True` (as specified by
         BlockingQueue.offer(Object,long,TimeUnit) BlockingQueue.offer)

        Raises
        - ClassCastException: if the specified element cannot be compared
                with elements currently in the priority queue according to the
                priority queue's ordering
        - NullPointerException: if the specified element is null
        """
        ...


    def poll(self) -> "E":
        ...


    def take(self) -> "E":
        ...


    def poll(self, timeout: int, unit: "TimeUnit") -> "E":
        ...


    def peek(self) -> "E":
        ...


    def comparator(self) -> "Comparator"["E"]:
        """
        Returns the comparator used to order the elements in this queue,
        or `null` if this queue uses the Comparable
        natural ordering of its elements.

        Returns
        - the comparator used to order the elements in this queue,
                or `null` if this queue uses the natural
                ordering of its elements
        """
        ...


    def size(self) -> int:
        ...


    def remainingCapacity(self) -> int:
        """
        Always returns `Integer.MAX_VALUE` because
        a `PriorityBlockingQueue` is not capacity constrained.

        Returns
        - `Integer.MAX_VALUE` always
        """
        ...


    def remove(self, o: "Object") -> bool:
        """
        Removes a single instance of the specified element from this queue,
        if it is present.  More formally, removes an element `e` such
        that `o.equals(e)`, if this queue contains one or more such
        elements.  Returns `True` if and only if this queue contained
        the specified element (or equivalently, if this queue changed as a
        result of the call).

        Arguments
        - o: element to be removed from this queue, if present

        Returns
        - `True` if this queue changed as a result of the call
        """
        ...


    def contains(self, o: "Object") -> bool:
        """
        Returns `True` if this queue contains the specified element.
        More formally, returns `True` if and only if this queue contains
        at least one element `e` such that `o.equals(e)`.

        Arguments
        - o: object to be checked for containment in this queue

        Returns
        - `True` if this queue contains the specified element
        """
        ...


    def toString(self) -> str:
        ...


    def drainTo(self, c: Iterable["E"]) -> int:
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 
        """
        ...


    def drainTo(self, c: Iterable["E"], maxElements: int) -> int:
        """
        Raises
        - UnsupportedOperationException: 
        - ClassCastException: 
        - NullPointerException: 
        - IllegalArgumentException: 
        """
        ...


    def clear(self) -> None:
        """
        Atomically removes all of the elements from this queue.
        The queue will be empty after this call returns.
        """
        ...


    def toArray(self) -> list["Object"]:
        """
        Returns an array containing all of the elements in this queue.
        The returned array elements are in no particular order.
        
        The returned array will be "safe" in that no references to it are
        maintained by this queue.  (In other words, this method must allocate
        a new array).  The caller is thus free to modify the returned array.
        
        This method acts as bridge between array-based and collection-based
        APIs.

        Returns
        - an array containing all of the elements in this queue
        """
        ...


    def toArray(self, a: list["T"]) -> list["T"]:
        """
        Returns an array containing all of the elements in this queue; the
        runtime type of the returned array is that of the specified array.
        The returned array elements are in no particular order.
        If the queue fits in the specified array, it is returned therein.
        Otherwise, a new array is allocated with the runtime type of the
        specified array and the size of this queue.
        
        If this queue fits in the specified array with room to spare
        (i.e., the array has more elements than this queue), the element in
        the array immediately following the end of the queue is set to
        `null`.
        
        Like the .toArray() method, this method acts as bridge between
        array-based and collection-based APIs.  Further, this method allows
        precise control over the runtime type of the output array, and may,
        under certain circumstances, be used to save allocation costs.
        
        Suppose `x` is a queue known to contain only strings.
        The following code can be used to dump the queue into a newly
        allocated array of `String`:
        
        ``` `String[] y = x.toArray(new String[0]);````
        
        Note that `toArray(new Object[0])` is identical in function to
        `toArray()`.

        Arguments
        - a: the array into which the elements of the queue are to
                 be stored, if it is big enough; otherwise, a new array of the
                 same runtime type is allocated for this purpose

        Returns
        - an array containing all of the elements in this queue

        Raises
        - ArrayStoreException: if the runtime type of the specified array
                is not a supertype of the runtime type of every element in
                this queue
        - NullPointerException: if the specified array is null
        """
        ...


    def iterator(self) -> Iterator["E"]:
        """
        Returns an iterator over the elements in this queue. The
        iterator does not return the elements in any particular order.
        
        The returned iterator is
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.

        Returns
        - an iterator over the elements in this queue
        """
        ...


    def spliterator(self) -> "Spliterator"["E"]:
        """
        Returns a Spliterator over the elements in this queue.
        The spliterator does not traverse elements in any particular order
        (the Spliterator.ORDERED ORDERED characteristic is not reported).
        
        The returned spliterator is
        <a href="package-summary.html#Weakly">*weakly consistent*</a>.
        
        The `Spliterator` reports Spliterator.SIZED and
        Spliterator.NONNULL.

        Returns
        - a `Spliterator` over the elements in this queue

        Since
        - 1.8

        Unknown Tags
        - The `Spliterator` additionally reports Spliterator.SUBSIZED.
        """
        ...


    def removeIf(self, filter: "Predicate"["E"]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def removeAll(self, c: Iterable[Any]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def retainAll(self, c: Iterable[Any]) -> bool:
        """
        Raises
        - NullPointerException: 
        """
        ...


    def forEach(self, action: "Consumer"["E"]) -> None:
        """
        Raises
        - NullPointerException: 
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerInteractEntityEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from org.bukkit.inventory import EquipmentSlot
from typing import Any, Callable, Iterable, Tuple


class PlayerInteractEntityEvent(PlayerEvent, Cancellable):
    """
    Represents an event that is called when a player right clicks an entity.
    """

    def __init__(self, who: "Player", clickedEntity: "Entity"):
        ...


    def __init__(self, who: "Player", clickedEntity: "Entity", hand: "EquipmentSlot"):
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getRightClicked(self) -> "Entity":
        """
        Gets the entity that was right-clicked by the player.

        Returns
        - entity right clicked by player
        """
        ...


    def getHand(self) -> "EquipmentSlot":
        """
        The hand used to perform this interaction.

        Returns
        - the hand used to interact
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.AbstractNavigableMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.collect import *
from com.google.common.collect.Maps import IteratorBasedAbstractMap
from java.util import Iterator
from java.util import NavigableMap
from java.util import NavigableSet
from java.util import NoSuchElementException
from java.util import SortedMap
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractNavigableMap(IteratorBasedAbstractMap, NavigableMap):
    """
    Skeletal implementation of NavigableMap.

    Author(s)
    - Louis Wasserman
    """

    def get(self, key: "Object") -> "V":
        ...


    def firstEntry(self) -> "Entry"["K", "V"]:
        ...


    def lastEntry(self) -> "Entry"["K", "V"]:
        ...


    def pollFirstEntry(self) -> "Entry"["K", "V"]:
        ...


    def pollLastEntry(self) -> "Entry"["K", "V"]:
        ...


    def firstKey(self) -> "K":
        ...


    def lastKey(self) -> "K":
        ...


    def lowerEntry(self, key: "K") -> "Entry"["K", "V"]:
        ...


    def floorEntry(self, key: "K") -> "Entry"["K", "V"]:
        ...


    def ceilingEntry(self, key: "K") -> "Entry"["K", "V"]:
        ...


    def higherEntry(self, key: "K") -> "Entry"["K", "V"]:
        ...


    def lowerKey(self, key: "K") -> "K":
        ...


    def floorKey(self, key: "K") -> "K":
        ...


    def ceilingKey(self, key: "K") -> "K":
        ...


    def higherKey(self, key: "K") -> "K":
        ...


    def subMap(self, fromKey: "K", toKey: "K") -> "SortedMap"["K", "V"]:
        ...


    def headMap(self, toKey: "K") -> "SortedMap"["K", "V"]:
        ...


    def tailMap(self, fromKey: "K") -> "SortedMap"["K", "V"]:
        ...


    def navigableKeySet(self) -> "NavigableSet"["K"]:
        ...


    def keySet(self) -> set["K"]:
        ...


    def descendingKeySet(self) -> "NavigableSet"["K"]:
        ...


    def descendingMap(self) -> "NavigableMap"["K", "V"]:
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BellResonateEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.entity import LivingEntity
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BellResonateEvent(BlockEvent):
    """
    Called when a bell resonated after being rung and highlights nearby raiders.
    A bell will only resonate if raiders are in the vicinity of the bell.
    """

    def __init__(self, theBlock: "Block", resonatedEntities: list["LivingEntity"]):
        ...


    def getResonatedEntities(self) -> list["LivingEntity"]:
        """
        Get a mutable list of all LivingEntity LivingEntities to be
        highlighted by the bell's resonating. This list can be added to or
        removed from to change which entities are highlighted, and may be empty
        if no entities were resonated as a result of this event.
        
        While the highlighted entities will change, the particles that display
        over a resonated entity and their colors will not. This is handled by the
        client and cannot be controlled by the server.

        Returns
        - a list of resonated entities
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.FluentIterable

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.base import Function
from com.google.common.base import Joiner
from com.google.common.base import Optional
from com.google.common.base import Predicate
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import InlineMe
from java.util import Arrays
from java.util import Collections
from java.util import Comparator
from java.util import Iterator
from java.util import SortedSet
from java.util.stream import Stream
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import NonNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class FluentIterable(Iterable):
    """
    A discouraged (but not deprecated) precursor to Java's superior Stream library.
    
    The following types of methods are provided:
    
    
      - chaining methods which return a new `FluentIterable` based in some way on the
          contents of the current one (for example .transform)
      - element extraction methods which facilitate the retrieval of certain elements (for example
          .last)
      - query methods which answer questions about the `FluentIterable`'s contents (for
          example .anyMatch)
      - conversion methods which copy the `FluentIterable`'s contents into a new collection
          or array (for example .toList)
    
    
    Several lesser-used features are currently available only as static methods on the Iterables class.
    
    <a id="streams"></a>
    
    <h3>Comparison to streams</h3>
    
    Stream is similar to this class, but generally more powerful, and certainly more
    standard. Key differences include:
    
    
      - A stream is *single-use*; it becomes invalid as soon as any "terminal operation" such
          as `findFirst()` or `iterator()` is invoked. (Even though `Stream`
          contains all the right method *signatures* to implement Iterable, it does not
          actually do so, to avoid implying repeat-iterability.) `FluentIterable`, on the other
          hand, is multiple-use, and does implement Iterable.
      - Streams offer many features not found here, including `min/max`, `distinct`,
          `reduce`, `sorted`, the very powerful `collect`, and built-in support for
          parallelizing stream operations.
      - `FluentIterable` contains several features not available on `Stream`, which are
          noted in the method descriptions below.
      - Streams include primitive-specialized variants such as `IntStream`, the use of which
          is strongly recommended.
      - Streams are standard Java, not requiring a third-party dependency.
    
    
    <h3>Example</h3>
    
    Here is an example that accepts a list from a database call, filters it based on a predicate,
    transforms it by invoking `toString()` on each element, and returns the first 10 elements
    as a `List`:
    
    ````ImmutableList<String> results =
        FluentIterable.from(database.getClientList())
            .filter(Client::isActiveInLastMonth)
            .transform(Object::toString)
            .limit(10)
            .toList();````
    
    The approximate stream equivalent is:
    
    ````List<String> results =
        database.getClientList()
            .stream()
            .filter(Client::isActiveInLastMonth)
            .map(Object::toString)
            .limit(10)
            .collect(Collectors.toList());````

    Author(s)
    - Marcin Mikosik

    Since
    - 12.0
    """

    @staticmethod
    def from(iterable: Iterable["E"]) -> "FluentIterable"["E"]:
        """
        Returns a fluent iterable that wraps `iterable`, or `iterable` itself if it is
        already a `FluentIterable`.
        
        **`Stream` equivalent:** Collection.stream if `iterable` is a Collection; Streams.stream(Iterable) otherwise.
        """
        ...


    @staticmethod
    def from(elements: list["E"]) -> "FluentIterable"["E"]:
        """
        Returns a fluent iterable containing `elements` in the specified order.
        
        The returned iterable is an unmodifiable view of the input array.
        
        **`Stream` equivalent:** java.util.stream.Stream.of(Object[])
        Stream.of(T...).

        Since
        - 20.0 (since 18.0 as an overload of `of`)
        """
        ...


    @staticmethod
    def from(iterable: "FluentIterable"["E"]) -> "FluentIterable"["E"]:
        """
        Construct a fluent iterable from another fluent iterable. This is obviously never necessary,
        but is intended to help call out cases where one migration from `Iterable` to `FluentIterable` has obviated the need to explicitly convert to a `FluentIterable`.

        Deprecated
        - instances of `FluentIterable` don't need to be converted to `FluentIterable`
        """
        ...


    @staticmethod
    def concat(a: Iterable["T"], b: Iterable["T"]) -> "FluentIterable"["T"]:
        """
        Returns a fluent iterable that combines two iterables. The returned iterable has an iterator
        that traverses the elements in `a`, followed by the elements in `b`. The source
        iterators are not polled until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it.
        
        **`Stream` equivalent:** Stream.concat.

        Since
        - 20.0
        """
        ...


    @staticmethod
    def concat(a: Iterable["T"], b: Iterable["T"], c: Iterable["T"]) -> "FluentIterable"["T"]:
        """
        Returns a fluent iterable that combines three iterables. The returned iterable has an iterator
        that traverses the elements in `a`, followed by the elements in `b`, followed by
        the elements in `c`. The source iterators are not polled until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it.
        
        **`Stream` equivalent:** use nested calls to Stream.concat, or see the
        advice in .concat(Iterable...).

        Since
        - 20.0
        """
        ...


    @staticmethod
    def concat(a: Iterable["T"], b: Iterable["T"], c: Iterable["T"], d: Iterable["T"]) -> "FluentIterable"["T"]:
        """
        Returns a fluent iterable that combines four iterables. The returned iterable has an iterator
        that traverses the elements in `a`, followed by the elements in `b`, followed by
        the elements in `c`, followed by the elements in `d`. The source iterators are not
        polled until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it.
        
        **`Stream` equivalent:** use nested calls to Stream.concat, or see the
        advice in .concat(Iterable...).

        Since
        - 20.0
        """
        ...


    @staticmethod
    def concat(*inputs: Tuple[Iterable["T"], ...]) -> "FluentIterable"["T"]:
        """
        Returns a fluent iterable that combines several iterables. The returned iterable has an
        iterator that traverses the elements of each iterable in `inputs`. The input iterators
        are not polled until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it.
        
        **`Stream` equivalent:** to concatenate an arbitrary number of streams, use `Stream.of(stream1, stream2, ...).flatMap(s -> s)`. If the sources are iterables, use `Stream.of(iter1, iter2, ...).flatMap(Streams::stream)`.

        Raises
        - NullPointerException: if any of the provided iterables is `null`

        Since
        - 20.0
        """
        ...


    @staticmethod
    def concat(inputs: Iterable[Iterable["T"]]) -> "FluentIterable"["T"]:
        """
        Returns a fluent iterable that combines several iterables. The returned iterable has an
        iterator that traverses the elements of each iterable in `inputs`. The input iterators
        are not polled until necessary.
        
        The returned iterable's iterator supports `remove()` when the corresponding input
        iterator supports it. The methods of the returned iterable may throw `NullPointerException` if any of the input iterators is `null`.
        
        **`Stream` equivalent:** `streamOfStreams.flatMap(s -> s)` or `streamOfIterables.flatMap(Streams::stream)`. (See Streams.stream.)

        Since
        - 20.0
        """
        ...


    @staticmethod
    def of() -> "FluentIterable"["E"]:
        """
        Returns a fluent iterable containing no elements.
        
        **`Stream` equivalent:** Stream.empty.

        Since
        - 20.0
        """
        ...


    @staticmethod
    def of(element: "E", *elements: Tuple["E", ...]) -> "FluentIterable"["E"]:
        """
        Returns a fluent iterable containing the specified elements in order.
        
        **`Stream` equivalent:** java.util.stream.Stream.of(Object[])
        Stream.of(T...).

        Since
        - 20.0
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation of this fluent iterable, with the format `[e1, e2, ...,
        en]`.
        
        **`Stream` equivalent:** `stream.collect(Collectors.joining(", ", "[", "]"))`
        or (less efficiently) `stream.collect(Collectors.toList()).toString()`.
        """
        ...


    def size(self) -> int:
        """
        Returns the number of elements in this fluent iterable.
        
        **`Stream` equivalent:** Stream.count.
        """
        ...


    def contains(self, target: "Object") -> bool:
        """
        Returns `True` if this fluent iterable contains any object for which `equals(target)` is True.
        
        **`Stream` equivalent:** `stream.anyMatch(Predicate.isEqual(target))`.
        """
        ...


    def cycle(self) -> "FluentIterable"["E"]:
        """
        Returns a fluent iterable whose `Iterator` cycles indefinitely over the elements of this
        fluent iterable.
        
        That iterator supports `remove()` if `iterable.iterator()` does. After `remove()` is called, subsequent cycles omit the removed element, which is no longer in this
        fluent iterable. The iterator's `hasNext()` method returns `True` until this fluent
        iterable is empty.
        
        **Warning:** Typical uses of the resulting iterator may produce an infinite loop. You
        should use an explicit `break` or be certain that you will eventually remove all the
        elements.
        
        **`Stream` equivalent:** if the source iterable has only a single element `e`, use `Stream.generate(() -> e)`. Otherwise, collect your stream into a collection and
        use `Stream.generate(() -> collection).flatMap(Collection::stream)`.
        """
        ...


    def append(self, other: Iterable["E"]) -> "FluentIterable"["E"]:
        """
        Returns a fluent iterable whose iterators traverse first the elements of this fluent iterable,
        followed by those of `other`. The iterators are not polled until necessary.
        
        The returned iterable's `Iterator` supports `remove()` when the corresponding
        `Iterator` supports it.
        
        **`Stream` equivalent:** Stream.concat.

        Since
        - 18.0
        """
        ...


    def append(self, *elements: Tuple["E", ...]) -> "FluentIterable"["E"]:
        """
        Returns a fluent iterable whose iterators traverse first the elements of this fluent iterable,
        followed by `elements`.
        
        **`Stream` equivalent:** `Stream.concat(thisStream, Stream.of(elements))`.

        Since
        - 18.0
        """
        ...


    def filter(self, predicate: "Predicate"["E"]) -> "FluentIterable"["E"]:
        """
        Returns the elements from this fluent iterable that satisfy a predicate. The resulting fluent
        iterable's iterator does not support `remove()`.
        
        **`Stream` equivalent:** Stream.filter (same).
        """
        ...


    def filter(self, type: type["T"]) -> "FluentIterable"["T"]:
        """
        Returns the elements from this fluent iterable that are instances of class `type`.
        
        **`Stream` equivalent:** `stream.filter(type::isInstance).map(type::cast)`.
        This does perform a little more work than necessary, so another option is to insert an
        unchecked cast at some later point:
        
        ```
        `@SuppressWarnings("unchecked") // safe because of ::isInstance check
        ImmutableList<NewType> result =
            (ImmutableList) stream.filter(NewType.class::isInstance).collect(toImmutableList());`
        ```
        """
        ...


    def anyMatch(self, predicate: "Predicate"["E"]) -> bool:
        """
        Returns `True` if any element in this fluent iterable satisfies the predicate.
        
        **`Stream` equivalent:** Stream.anyMatch (same).
        """
        ...


    def allMatch(self, predicate: "Predicate"["E"]) -> bool:
        """
        Returns `True` if every element in this fluent iterable satisfies the predicate. If this
        fluent iterable is empty, `True` is returned.
        
        **`Stream` equivalent:** Stream.allMatch (same).
        """
        ...


    def firstMatch(self, predicate: "Predicate"["E"]) -> "Optional"["E"]:
        """
        Returns an Optional containing the first element in this fluent iterable that satisfies
        the given predicate, if such an element exists.
        
        **Warning:** avoid using a `predicate` that matches `null`. If `null`
        is matched in this fluent iterable, a NullPointerException will be thrown.
        
        **`Stream` equivalent:** `stream.filter(predicate).findFirst()`.
        """
        ...


    def transform(self, function: "Function"["E", "T"]) -> "FluentIterable"["T"]:
        """
        Returns a fluent iterable that applies `function` to each element of this fluent
        iterable.
        
        The returned fluent iterable's iterator supports `remove()` if this iterable's
        iterator does. After a successful `remove()` call, this fluent iterable no longer
        contains the corresponding element.
        
        **`Stream` equivalent:** Stream.map.
        """
        ...


    def transformAndConcat(self, function: "Function"["E", Iterable["T"]]) -> "FluentIterable"["T"]:
        """
        Applies `function` to each element of this fluent iterable and returns a fluent iterable
        with the concatenated combination of results. `function` returns an Iterable of results.
        
        The returned fluent iterable's iterator supports `remove()` if this function-returned
        iterables' iterator does. After a successful `remove()` call, the returned fluent
        iterable no longer contains the corresponding element.
        
        **`Stream` equivalent:** Stream.flatMap (using a function that produces
        streams, not iterables).

        Since
        - 13.0 (required `Function<E, Iterable<T>>` until 14.0)
        """
        ...


    def first(self) -> "Optional"["E"]:
        """
        Returns an Optional containing the first element in this fluent iterable. If the
        iterable is empty, `Optional.absent()` is returned.
        
        **`Stream` equivalent:** if the goal is to obtain any element, Stream.findAny; if it must specifically be the *first* element, `Stream.findFirst`.

        Raises
        - NullPointerException: if the first element is null; if this is a possibility, use `iterator().next()` or Iterables.getFirst instead.
        """
        ...


    def last(self) -> "Optional"["E"]:
        """
        Returns an Optional containing the last element in this fluent iterable. If the
        iterable is empty, `Optional.absent()` is returned. If the underlying `iterable` is
        a List with java.util.RandomAccess support, then this operation is guaranteed
        to be `O(1)`.
        
        **`Stream` equivalent:** `stream.reduce((a, b) -> b)`.

        Raises
        - NullPointerException: if the last element is null; if this is a possibility, use Iterables.getLast instead.
        """
        ...


    def skip(self, numberToSkip: int) -> "FluentIterable"["E"]:
        """
        Returns a view of this fluent iterable that skips its first `numberToSkip` elements. If
        this fluent iterable contains fewer than `numberToSkip` elements, the returned fluent
        iterable skips all of its elements.
        
        Modifications to this fluent iterable before a call to `iterator()` are reflected in
        the returned fluent iterable. That is, the iterator skips the first `numberToSkip`
        elements that exist when the iterator is created, not when `skip()` is called.
        
        The returned fluent iterable's iterator supports `remove()` if the `Iterator` of
        this fluent iterable supports it. Note that it is *not* possible to delete the last
        skipped element by immediately calling `remove()` on the returned fluent iterable's
        iterator, as the `Iterator` contract states that a call to `* remove()` before a
        call to `next()` will throw an IllegalStateException.
        
        **`Stream` equivalent:** Stream.skip (same).
        """
        ...


    def limit(self, maxSize: int) -> "FluentIterable"["E"]:
        """
        Creates a fluent iterable with the first `size` elements of this fluent iterable. If this
        fluent iterable does not contain that many elements, the returned fluent iterable will have the
        same behavior as this fluent iterable. The returned fluent iterable's iterator supports `remove()` if this fluent iterable's iterator does.
        
        **`Stream` equivalent:** Stream.limit (same).

        Arguments
        - maxSize: the maximum number of elements in the returned fluent iterable

        Raises
        - IllegalArgumentException: if `size` is negative
        """
        ...


    def isEmpty(self) -> bool:
        """
        Determines whether this fluent iterable is empty.
        
        **`Stream` equivalent:** `!stream.findAny().isPresent()`.
        """
        ...


    def toList(self) -> "ImmutableList"["E"]:
        """
        Returns an `ImmutableList` containing all of the elements from this fluent iterable in
        proper sequence.
        
        **`Stream` equivalent:** pass ImmutableList.toImmutableList to `stream.collect()`.

        Raises
        - NullPointerException: if any element is `null`

        Since
        - 14.0 (since 12.0 as `toImmutableList()`).
        """
        ...


    def toSortedList(self, comparator: "Comparator"["E"]) -> "ImmutableList"["E"]:
        """
        Returns an `ImmutableList` containing all of the elements from this `FluentIterable` in the order specified by `comparator`. To produce an `ImmutableList` sorted by its natural ordering, use `toSortedList(Ordering.natural())`.
        
        **`Stream` equivalent:** pass ImmutableList.toImmutableList to `stream.sorted(comparator).collect()`.

        Arguments
        - comparator: the function by which to sort list elements

        Raises
        - NullPointerException: if any element of this iterable is `null`

        Since
        - 14.0 (since 13.0 as `toSortedImmutableList()`).
        """
        ...


    def toSet(self) -> "ImmutableSet"["E"]:
        """
        Returns an `ImmutableSet` containing all of the elements from this fluent iterable with
        duplicates removed.
        
        **`Stream` equivalent:** pass ImmutableSet.toImmutableSet to `stream.collect()`.

        Raises
        - NullPointerException: if any element is `null`

        Since
        - 14.0 (since 12.0 as `toImmutableSet()`).
        """
        ...


    def toSortedSet(self, comparator: "Comparator"["E"]) -> "ImmutableSortedSet"["E"]:
        """
        Returns an `ImmutableSortedSet` containing all of the elements from this `FluentIterable` in the order specified by `comparator`, with duplicates (determined by
        `comparator.compare(x, y) == 0`) removed. To produce an `ImmutableSortedSet` sorted
        by its natural ordering, use `toSortedSet(Ordering.natural())`.
        
        **`Stream` equivalent:** pass ImmutableSortedSet.toImmutableSortedSet to
        `stream.collect()`.

        Arguments
        - comparator: the function by which to sort set elements

        Raises
        - NullPointerException: if any element of this iterable is `null`

        Since
        - 14.0 (since 12.0 as `toImmutableSortedSet()`).
        """
        ...


    def toMultiset(self) -> "ImmutableMultiset"["E"]:
        """
        Returns an `ImmutableMultiset` containing all of the elements from this fluent iterable.
        
        **`Stream` equivalent:** pass ImmutableMultiset.toImmutableMultiset to
        `stream.collect()`.

        Raises
        - NullPointerException: if any element is null

        Since
        - 19.0
        """
        ...


    def toMap(self, valueFunction: "Function"["E", "V"]) -> "ImmutableMap"["E", "V"]:
        """
        Returns an immutable map whose keys are the distinct elements of this `FluentIterable`
        and whose value for each key was computed by `valueFunction`. The map's iteration order
        is the order of the first appearance of each key in this iterable.
        
        When there are multiple instances of a key in this iterable, it is unspecified whether
        `valueFunction` will be applied to more than one instance of that key and, if it is,
        which result will be mapped to that key in the returned map.
        
        **`Stream` equivalent:** `stream.collect(ImmutableMap.toImmutableMap(k -> k,
        valueFunction))`.

        Raises
        - NullPointerException: if any element of this iterable is `null`, or if `valueFunction` produces `null` for any key

        Since
        - 14.0
        """
        ...


    def index(self, keyFunction: "Function"["E", "K"]) -> "ImmutableListMultimap"["K", "E"]:
        """
        Creates an index `ImmutableListMultimap` that contains the results of applying a
        specified function to each item in this `FluentIterable` of values. Each element of this
        iterable will be stored as a value in the resulting multimap, yielding a multimap with the same
        size as this iterable. The key used to store that value in the multimap will be the result of
        calling the function on that value. The resulting multimap is created as an immutable snapshot.
        In the returned multimap, keys appear in the order they are first encountered, and the values
        corresponding to each key appear in the same order as they are encountered.
        
        **`Stream` equivalent:** `stream.collect(Collectors.groupingBy(keyFunction))`
        behaves similarly, but returns a mutable `Map<K, List<E>>` instead, and may not preserve
        the order of entries.

        Arguments
        - keyFunction: the function used to produce the key for each value

        Raises
        - NullPointerException: if any element of this iterable is `null`, or if `keyFunction` produces `null` for any key

        Since
        - 14.0
        """
        ...


    def uniqueIndex(self, keyFunction: "Function"["E", "K"]) -> "ImmutableMap"["K", "E"]:
        """
        Returns a map with the contents of this `FluentIterable` as its `values`, indexed
        by keys derived from those values. In other words, each input value produces an entry in the
        map whose key is the result of applying `keyFunction` to that value. These entries appear
        in the same order as they appeared in this fluent iterable. Example usage:
        
        ````Color red = new Color("red", 255, 0, 0);
        ...
        FluentIterable<Color> allColors = FluentIterable.from(ImmutableSet.of(red, green, blue));
        
        Map<String, Color> colorForName = allColors.uniqueIndex(toStringFunction());
        assertThat(colorForName).containsEntry("red", red);````
        
        If your index may associate multiple values with each key, use .index(Function)
        index.
        
        **`Stream` equivalent:** `stream.collect(ImmutableMap.toImmutableMap(keyFunction, v -> v))`.

        Arguments
        - keyFunction: the function used to produce the key for each value

        Returns
        - a map mapping the result of evaluating the function `keyFunction` on each value
            in this fluent iterable to that value

        Raises
        - IllegalArgumentException: if `keyFunction` produces the same key for more than one
            value in this fluent iterable
        - NullPointerException: if any element of this iterable is `null`, or if `keyFunction` produces `null` for any key

        Since
        - 14.0
        """
        ...


    def toArray(self, type: type["E"]) -> list["E"]:
        """
        Returns an array containing all of the elements from this fluent iterable in iteration order.
        
        **`Stream` equivalent:** if an object array is acceptable, use `stream.toArray()`; if `type` is a class literal such as `MyType.class`, use `stream.toArray(MyType[]::new)`. Otherwise use `stream.toArray( len -> (E[])
        Array.newInstance(type, len))`.

        Arguments
        - type: the type of the elements

        Returns
        - a newly-allocated array into which all the elements of this fluent iterable have been
            copied
        """
        ...


    def copyInto(self, collection: "C") -> "C":
        """
        Copies all the elements from this fluent iterable to `collection`. This is equivalent to
        calling `Iterables.addAll(collection, this)`.
        
        **`Stream` equivalent:** `stream.forEachOrdered(collection::add)` or `stream.forEach(collection::add)`.

        Arguments
        - collection: the collection to copy elements to

        Returns
        - `collection`, for convenience

        Since
        - 14.0
        """
        ...


    def join(self, joiner: "Joiner") -> str:
        """
        Returns a String containing all of the elements of this fluent iterable joined with
        `joiner`.
        
        **`Stream` equivalent:** `joiner.join(stream.iterator())`, or, if you are not
        using any optional `Joiner` features, `stream.collect(Collectors.joining(delimiter)`.

        Since
        - 18.0
        """
        ...


    def get(self, position: int) -> "E":
        """
        Returns the element at the specified position in this fluent iterable.
        
        **`Stream` equivalent:** `stream.skip(position).findFirst().get()` (but note
        that this throws different exception types, and throws an exception if `null` would be
        returned).

        Arguments
        - position: position of the element to return

        Returns
        - the element at the specified position in this fluent iterable

        Raises
        - IndexOutOfBoundsException: if `position` is negative or greater than or equal to
            the size of this fluent iterable
        """
        ...


    def stream(self) -> "Stream"["E"]:
        """
        Returns a stream of this fluent iterable's contents (similar to calling Collection.stream on a collection).
        
        **Note:** the earlier in the chain you can switch to `Stream` usage (ideally not
        going through `FluentIterable` at all), the more performant and idiomatic your code will
        be. This method is a transitional aid, to be used only when really necessary.

        Since
        - 21.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityDeathEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.damage import DamageSource
from org.bukkit.entity import LivingEntity
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class EntityDeathEvent(EntityEvent):
    """
    Thrown whenever a LivingEntity dies
    """

    def __init__(self, entity: "LivingEntity", damageSource: "DamageSource", drops: list["ItemStack"]):
        ...


    def __init__(self, what: "LivingEntity", damageSource: "DamageSource", drops: list["ItemStack"], droppedExp: int):
        ...


    def getEntity(self) -> "LivingEntity":
        ...


    def getDamageSource(self) -> "DamageSource":
        """
        Gets the source of damage which caused the death.

        Returns
        - a DamageSource detailing the source of the damage for the death.
        """
        ...


    def getDroppedExp(self) -> int:
        """
        Gets how much EXP should be dropped from this death.
        
        This does not indicate how much EXP should be taken from the entity in
        question, merely how much should be created after its death.

        Returns
        - Amount of EXP to drop.
        """
        ...


    def setDroppedExp(self, exp: int) -> None:
        """
        Sets how much EXP should be dropped from this death.
        
        This does not indicate how much EXP should be taken from the entity in
        question, merely how much should be created after its death.

        Arguments
        - exp: Amount of EXP to drop.
        """
        ...


    def getDrops(self) -> list["ItemStack"]:
        """
        Gets all the items which will drop when the entity dies

        Returns
        - Items to drop when the entity dies
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.io.PrintStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.nio.charset import Charset
from java.nio.charset import IllegalCharsetNameException
from java.nio.charset import UnsupportedCharsetException
from java.util import Formatter
from java.util import Locale
from typing import Any, Callable, Iterable, Tuple


class PrintStream(FilterOutputStream, Appendable, Closeable):

    def __init__(self, out: "OutputStream"):
        """
        Creates a new print stream, without automatic line flushing, with the
        specified OutputStream. Characters written to the stream are converted
        to bytes using the platform's default character encoding.

        Arguments
        - out: The output stream to which values and objects will be
                           printed

        See
        - java.io.PrintWriter.PrintWriter(java.io.OutputStream)
        """
        ...


    def __init__(self, out: "OutputStream", autoFlush: bool):
        """
        Creates a new print stream, with the specified OutputStream and line
        flushing. Characters written to the stream are converted to bytes using
        the platform's default character encoding.

        Arguments
        - out: The output stream to which values and objects will be
                           printed
        - autoFlush: Whether the output buffer will be flushed
                           whenever a byte array is written, one of the
                           `println` methods is invoked, or a newline
                           character or byte (`'\n'`) is written

        See
        - java.io.PrintWriter.PrintWriter(java.io.OutputStream, boolean)
        """
        ...


    def __init__(self, out: "OutputStream", autoFlush: bool, encoding: str):
        """
        Creates a new print stream, with the specified OutputStream, line
        flushing, and character encoding.

        Arguments
        - out: The output stream to which values and objects will be
                           printed
        - autoFlush: Whether the output buffer will be flushed
                           whenever a byte array is written, one of the
                           `println` methods is invoked, or a newline
                           character or byte (`'\n'`) is written
        - encoding: The name of a supported
                           <a href="../lang/package-summary.html#charenc">
                           character encoding</a>

        Raises
        - UnsupportedEncodingException: If the named encoding is not supported

        Since
        - 1.4
        """
        ...


    def __init__(self, out: "OutputStream", autoFlush: bool, charset: "Charset"):
        """
        Creates a new print stream, with the specified OutputStream, line
        flushing and charset.  This convenience constructor creates the necessary
        intermediate java.io.OutputStreamWriter OutputStreamWriter,
        which will encode characters using the provided charset.

        Arguments
        - out: The output stream to which values and objects will be
                           printed
        - autoFlush: Whether the output buffer will be flushed
                           whenever a byte array is written, one of the
                           `println` methods is invoked, or a newline
                           character or byte (`'\n'`) is written
        - charset: A java.nio.charset.Charset charset

        Since
        - 10
        """
        ...


    def __init__(self, fileName: str):
        """
        Creates a new print stream, without automatic line flushing, with the
        specified file name.  This convenience constructor creates
        the necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the
        java.nio.charset.Charset.defaultCharset() default charset
        for this instance of the Java virtual machine.

        Arguments
        - fileName: The name of the file to use as the destination of this print
                stream.  If the file exists, then it will be truncated to
                zero size; otherwise, a new file will be created.  The output
                will be written to the file and is buffered.

        Raises
        - FileNotFoundException: If the given file object does not denote an existing, writable
                 regular file and a new regular file of that name cannot be
                 created, or if some other error occurs while opening or
                 creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(fileName) denies write
                 access to the file

        Since
        - 1.5
        """
        ...


    def __init__(self, fileName: str, csn: str):
        """
        Creates a new print stream, without automatic line flushing, with the
        specified file name and charset.  This convenience constructor creates
        the necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the provided
        charset.

        Arguments
        - fileName: The name of the file to use as the destination of this print
                stream.  If the file exists, then it will be truncated to
                zero size; otherwise, a new file will be created.  The output
                will be written to the file and is buffered.
        - csn: The name of a supported java.nio.charset.Charset
                charset

        Raises
        - FileNotFoundException: If the given file object does not denote an existing, writable
                 regular file and a new regular file of that name cannot be
                 created, or if some other error occurs while opening or
                 creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(fileName) denies write
                 access to the file
        - UnsupportedEncodingException: If the named charset is not supported

        Since
        - 1.5
        """
        ...


    def __init__(self, fileName: str, charset: "Charset"):
        """
        Creates a new print stream, without automatic line flushing, with the
        specified file name and charset.  This convenience constructor creates
        the necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the provided
        charset.

        Arguments
        - fileName: The name of the file to use as the destination of this print
                stream.  If the file exists, then it will be truncated to
                zero size; otherwise, a new file will be created.  The output
                will be written to the file and is buffered.
        - charset: A java.nio.charset.Charset charset

        Raises
        - IOException: if an I/O error occurs while opening or creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(fileName) denies write
                 access to the file

        Since
        - 10
        """
        ...


    def __init__(self, file: "File"):
        """
        Creates a new print stream, without automatic line flushing, with the
        specified file.  This convenience constructor creates the necessary
        intermediate java.io.OutputStreamWriter OutputStreamWriter,
        which will encode characters using the java.nio.charset.Charset.defaultCharset() default charset for this
        instance of the Java virtual machine.

        Arguments
        - file: The file to use as the destination of this print stream.  If the
                file exists, then it will be truncated to zero size; otherwise,
                a new file will be created.  The output will be written to the
                file and is buffered.

        Raises
        - FileNotFoundException: If the given file object does not denote an existing, writable
                 regular file and a new regular file of that name cannot be
                 created, or if some other error occurs while opening or
                 creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(file.getPath())
                 denies write access to the file

        Since
        - 1.5
        """
        ...


    def __init__(self, file: "File", csn: str):
        """
        Creates a new print stream, without automatic line flushing, with the
        specified file and charset.  This convenience constructor creates
        the necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the provided
        charset.

        Arguments
        - file: The file to use as the destination of this print stream.  If the
                file exists, then it will be truncated to zero size; otherwise,
                a new file will be created.  The output will be written to the
                file and is buffered.
        - csn: The name of a supported java.nio.charset.Charset
                charset

        Raises
        - FileNotFoundException: If the given file object does not denote an existing, writable
                 regular file and a new regular file of that name cannot be
                 created, or if some other error occurs while opening or
                 creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(file.getPath())
                 denies write access to the file
        - UnsupportedEncodingException: If the named charset is not supported

        Since
        - 1.5
        """
        ...


    def __init__(self, file: "File", charset: "Charset"):
        """
        Creates a new print stream, without automatic line flushing, with the
        specified file and charset.  This convenience constructor creates
        the necessary intermediate java.io.OutputStreamWriter
        OutputStreamWriter, which will encode characters using the provided
        charset.

        Arguments
        - file: The file to use as the destination of this print stream.  If the
                file exists, then it will be truncated to zero size; otherwise,
                a new file will be created.  The output will be written to the
                file and is buffered.
        - charset: A java.nio.charset.Charset charset

        Raises
        - IOException: if an I/O error occurs while opening or creating the file
        - SecurityException: If a security manager is present and SecurityManager.checkWrite checkWrite(file.getPath())
                 denies write access to the file

        Since
        - 10
        """
        ...


    def flush(self) -> None:
        """
        Flushes the stream.  This is done by writing any buffered output bytes to
        the underlying output stream and then flushing that stream.

        See
        - java.io.OutputStream.flush()
        """
        ...


    def close(self) -> None:
        """
        Closes the stream.  This is done by flushing the stream and then closing
        the underlying output stream.

        See
        - java.io.OutputStream.close()
        """
        ...


    def checkError(self) -> bool:
        """
        Flushes the stream and checks its error state. The internal error state
        is set to `True` when the underlying output stream throws an
        `IOException` other than `InterruptedIOException`,
        and when the `setError` method is invoked.  If an operation
        on the underlying output stream throws an
        `InterruptedIOException`, then the `PrintStream`
        converts the exception back into an interrupt by doing:
        ````Thread.currentThread().interrupt();````
        or the equivalent.

        Returns
        - `True` if and only if this stream has encountered an
                `IOException` other than
                `InterruptedIOException`, or the
                `setError` method has been invoked
        """
        ...


    def write(self, b: int) -> None:
        """
        Writes the specified byte to this stream.  If the byte is a newline and
        automatic flushing is enabled then the `flush` method will be
        invoked on the underlying output stream.
        
         Note that the byte is written as given; to write a character that
        will be translated according to the platform's default character
        encoding, use the `print(char)` or `println(char)`
        methods.

        Arguments
        - b: The byte to be written

        See
        - .println(char)
        """
        ...


    def write(self, buf: list[int], off: int, len: int) -> None:
        """
        Writes `len` bytes from the specified byte array starting at
        offset `off` to this stream.  If automatic flushing is
        enabled then the `flush` method will be invoked on the underlying
        output stream.
        
         Note that the bytes will be written as given; to write characters
        that will be translated according to the platform's default character
        encoding, use the `print(char)` or `println(char)`
        methods.

        Arguments
        - buf: A byte array
        - off: Offset from which to start taking bytes
        - len: Number of bytes to write
        """
        ...


    def write(self, buf: list[int]) -> None:
        """
        Writes all bytes from the specified byte array to this stream. If
        automatic flushing is enabled then the `flush` method will be
        invoked on the underlying output stream.
        
         Note that the bytes will be written as given; to write characters
        that will be translated according to the platform's default character
        encoding, use the `print(char[])` or `println(char[])`
        methods.

        Arguments
        - buf: A byte array

        Raises
        - IOException: If an I/O error occurs.

        See
        - .write(byte[],int,int)

        Since
        - 14

        Unknown Tags
        - Although declared to throw `IOException`, this method never
        actually does so. Instead, like other methods that this class
        overrides, it sets an internal flag which may be tested via the
        .checkError() method. To write an array of bytes without having
        to write a `catch` block for the `IOException`, use either
        .writeBytes(byte[] buf) writeBytes(buf) or
        .write(byte[], int, int) write(buf, 0, buf.length).
        - This method is equivalent to
        java.io.PrintStream.write(byte[],int,int)
        this.write(buf, 0, buf.length).
        """
        ...


    def writeBytes(self, buf: list[int]) -> None:
        """
        Writes all bytes from the specified byte array to this stream.
        If automatic flushing is enabled then the `flush` method
        will be invoked.
        
         Note that the bytes will be written as given; to write characters
        that will be translated according to the platform's default character
        encoding, use the `print(char[])` or `println(char[])`
        methods.

        Arguments
        - buf: A byte array

        Since
        - 14

        Unknown Tags
        - This method is equivalent to
        .write(byte[], int, int) this.write(buf, 0, buf.length).
        """
        ...


    def print(self, b: bool) -> None:
        """
        Prints a boolean value.  The string produced by java.lang.String.valueOf(boolean) is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the
        .write(int) method.

        Arguments
        - b: The `boolean` to be printed
        """
        ...


    def print(self, c: str) -> None:
        """
        Prints a character.  The character is translated into one or more bytes
        according to the character encoding given to the constructor, or the
        platform's default character encoding if none specified. These bytes
        are written in exactly the manner of the .write(int) method.

        Arguments
        - c: The `char` to be printed
        """
        ...


    def print(self, i: int) -> None:
        """
        Prints an integer.  The string produced by java.lang.String.valueOf(int) is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the
        .write(int) method.

        Arguments
        - i: The `int` to be printed

        See
        - java.lang.Integer.toString(int)
        """
        ...


    def print(self, l: int) -> None:
        """
        Prints a long integer.  The string produced by java.lang.String.valueOf(long) is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the
        .write(int) method.

        Arguments
        - l: The `long` to be printed

        See
        - java.lang.Long.toString(long)
        """
        ...


    def print(self, f: float) -> None:
        """
        Prints a floating-point number.  The string produced by java.lang.String.valueOf(float) is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the
        .write(int) method.

        Arguments
        - f: The `float` to be printed

        See
        - java.lang.Float.toString(float)
        """
        ...


    def print(self, d: float) -> None:
        """
        Prints a double-precision floating-point number.  The string produced by
        java.lang.String.valueOf(double) is translated into
        bytes according to the platform's default character encoding, and these
        bytes are written in exactly the manner of the .write(int) method.

        Arguments
        - d: The `double` to be printed

        See
        - java.lang.Double.toString(double)
        """
        ...


    def print(self, s: list[str]) -> None:
        """
        Prints an array of characters.  The characters are converted into bytes
        according to the character encoding given to the constructor, or the
        platform's default character encoding if none specified. These bytes
        are written in exactly the manner of the .write(int) method.

        Arguments
        - s: The array of chars to be printed

        Raises
        - NullPointerException: If `s` is `null`
        """
        ...


    def print(self, s: str) -> None:
        """
        Prints a string.  If the argument is `null` then the string
        `"null"` is printed.  Otherwise, the string's characters are
        converted into bytes according to the character encoding given to the
        constructor, or the platform's default character encoding if none
        specified. These bytes are written in exactly the manner of the
        .write(int) method.

        Arguments
        - s: The `String` to be printed
        """
        ...


    def print(self, obj: "Object") -> None:
        """
        Prints an object.  The string produced by the java.lang.String.valueOf(Object) method is translated into bytes
        according to the platform's default character encoding, and these bytes
        are written in exactly the manner of the
        .write(int) method.

        Arguments
        - obj: The `Object` to be printed

        See
        - java.lang.Object.toString()
        """
        ...


    def println(self) -> None:
        """
        Terminates the current line by writing the line separator string.  The
        line separator string is defined by the system property
        `line.separator`, and is not necessarily a single newline
        character (`'\n'`).
        """
        ...


    def println(self, x: bool) -> None:
        """
        Prints a boolean and then terminate the line.  This method behaves as
        though it invokes .print(boolean) and then
        .println().

        Arguments
        - x: The `boolean` to be printed
        """
        ...


    def println(self, x: str) -> None:
        """
        Prints a character and then terminate the line.  This method behaves as
        though it invokes .print(char) and then
        .println().

        Arguments
        - x: The `char` to be printed.
        """
        ...


    def println(self, x: int) -> None:
        """
        Prints an integer and then terminate the line.  This method behaves as
        though it invokes .print(int) and then
        .println().

        Arguments
        - x: The `int` to be printed.
        """
        ...


    def println(self, x: int) -> None:
        """
        Prints a long and then terminate the line.  This method behaves as
        though it invokes .print(long) and then
        .println().

        Arguments
        - x: a The `long` to be printed.
        """
        ...


    def println(self, x: float) -> None:
        """
        Prints a float and then terminate the line.  This method behaves as
        though it invokes .print(float) and then
        .println().

        Arguments
        - x: The `float` to be printed.
        """
        ...


    def println(self, x: float) -> None:
        """
        Prints a double and then terminate the line.  This method behaves as
        though it invokes .print(double) and then
        .println().

        Arguments
        - x: The `double` to be printed.
        """
        ...


    def println(self, x: list[str]) -> None:
        """
        Prints an array of characters and then terminate the line.  This method
        behaves as though it invokes .print(char[]) and
        then .println().

        Arguments
        - x: an array of chars to print.
        """
        ...


    def println(self, x: str) -> None:
        """
        Prints a String and then terminate the line.  This method behaves as
        though it invokes .print(String) and then
        .println().

        Arguments
        - x: The `String` to be printed.
        """
        ...


    def println(self, x: "Object") -> None:
        """
        Prints an Object and then terminate the line.  This method calls
        at first String.valueOf(x) to get the printed object's string value,
        then behaves as
        though it invokes .print(String) and then
        .println().

        Arguments
        - x: The `Object` to be printed.
        """
        ...


    def printf(self, format: str, *args: Tuple["Object", ...]) -> "PrintStream":
        """
        A convenience method to write a formatted string to this output stream
        using the specified format string and arguments.
        
         An invocation of this method of the form
        `out.printf(format, args)` behaves
        in exactly the same way as the invocation
        
        ````out.format(format, args)````

        Arguments
        - format: A format string as described in <a
                href="../util/Formatter.html#syntax">Format string syntax</a>
        - args: Arguments referenced by the format specifiers in the format
                string.  If there are more arguments than format specifiers, the
                extra arguments are ignored.  The number of arguments is
                variable and may be zero.  The maximum number of arguments is
                limited by the maximum dimension of a Java array as defined by
                <cite>The Java Virtual Machine Specification</cite>.
                The behaviour on a
                `null` argument depends on the <a
                href="../util/Formatter.html#syntax">conversion</a>.

        Returns
        - This output stream

        Raises
        - java.util.IllegalFormatException: If a format string contains an illegal syntax, a format
                 specifier that is incompatible with the given arguments,
                 insufficient arguments given the format string, or other
                 illegal conditions.  For specification of all possible
                 formatting errors, see the <a
                 href="../util/Formatter.html#detail">Details</a> section of the
                 formatter class specification.
        - NullPointerException: If the `format` is `null`

        Since
        - 1.5
        """
        ...


    def printf(self, l: "Locale", format: str, *args: Tuple["Object", ...]) -> "PrintStream":
        """
        A convenience method to write a formatted string to this output stream
        using the specified format string and arguments.
        
         An invocation of this method of the form
        `out.printf(l, format, args)` behaves
        in exactly the same way as the invocation
        
        ````out.format(l, format, args)````

        Arguments
        - l: The java.util.Locale locale to apply during
                formatting.  If `l` is `null` then no localization
                is applied.
        - format: A format string as described in <a
                href="../util/Formatter.html#syntax">Format string syntax</a>
        - args: Arguments referenced by the format specifiers in the format
                string.  If there are more arguments than format specifiers, the
                extra arguments are ignored.  The number of arguments is
                variable and may be zero.  The maximum number of arguments is
                limited by the maximum dimension of a Java array as defined by
                <cite>The Java Virtual Machine Specification</cite>.
                The behaviour on a
                `null` argument depends on the <a
                href="../util/Formatter.html#syntax">conversion</a>.

        Returns
        - This output stream

        Raises
        - java.util.IllegalFormatException: If a format string contains an illegal syntax, a format
                 specifier that is incompatible with the given arguments,
                 insufficient arguments given the format string, or other
                 illegal conditions.  For specification of all possible
                 formatting errors, see the <a
                 href="../util/Formatter.html#detail">Details</a> section of the
                 formatter class specification.
        - NullPointerException: If the `format` is `null`

        Since
        - 1.5
        """
        ...


    def format(self, format: str, *args: Tuple["Object", ...]) -> "PrintStream":
        """
        Writes a formatted string to this output stream using the specified
        format string and arguments.
        
         The locale always used is the one returned by java.util.Locale.getDefault(Locale.Category) with
        java.util.Locale.Category.FORMAT FORMAT category specified,
        regardless of any previous invocations of other formatting methods on
        this object.

        Arguments
        - format: A format string as described in <a
                href="../util/Formatter.html#syntax">Format string syntax</a>
        - args: Arguments referenced by the format specifiers in the format
                string.  If there are more arguments than format specifiers, the
                extra arguments are ignored.  The number of arguments is
                variable and may be zero.  The maximum number of arguments is
                limited by the maximum dimension of a Java array as defined by
                <cite>The Java Virtual Machine Specification</cite>.
                The behaviour on a
                `null` argument depends on the <a
                href="../util/Formatter.html#syntax">conversion</a>.

        Returns
        - This output stream

        Raises
        - java.util.IllegalFormatException: If a format string contains an illegal syntax, a format
                 specifier that is incompatible with the given arguments,
                 insufficient arguments given the format string, or other
                 illegal conditions.  For specification of all possible
                 formatting errors, see the <a
                 href="../util/Formatter.html#detail">Details</a> section of the
                 formatter class specification.
        - NullPointerException: If the `format` is `null`

        Since
        - 1.5
        """
        ...


    def format(self, l: "Locale", format: str, *args: Tuple["Object", ...]) -> "PrintStream":
        """
        Writes a formatted string to this output stream using the specified
        format string and arguments.

        Arguments
        - l: The java.util.Locale locale to apply during
                formatting.  If `l` is `null` then no localization
                is applied.
        - format: A format string as described in <a
                href="../util/Formatter.html#syntax">Format string syntax</a>
        - args: Arguments referenced by the format specifiers in the format
                string.  If there are more arguments than format specifiers, the
                extra arguments are ignored.  The number of arguments is
                variable and may be zero.  The maximum number of arguments is
                limited by the maximum dimension of a Java array as defined by
                <cite>The Java Virtual Machine Specification</cite>.
                The behaviour on a
                `null` argument depends on the <a
                href="../util/Formatter.html#syntax">conversion</a>.

        Returns
        - This output stream

        Raises
        - java.util.IllegalFormatException: If a format string contains an illegal syntax, a format
                 specifier that is incompatible with the given arguments,
                 insufficient arguments given the format string, or other
                 illegal conditions.  For specification of all possible
                 formatting errors, see the <a
                 href="../util/Formatter.html#detail">Details</a> section of the
                 formatter class specification.
        - NullPointerException: If the `format` is `null`

        Since
        - 1.5
        """
        ...


    def append(self, csq: "CharSequence") -> "PrintStream":
        """
        Appends the specified character sequence to this output stream.
        
         An invocation of this method of the form `out.append(csq)`
        behaves in exactly the same way as the invocation
        
        ````out.print(csq.toString())````
        
         Depending on the specification of `toString` for the
        character sequence `csq`, the entire sequence may not be
        appended.  For instance, invoking then `toString` method of a
        character buffer will return a subsequence whose content depends upon
        the buffer's position and limit.

        Arguments
        - csq: The character sequence to append.  If `csq` is
                `null`, then the four characters `"null"` are
                appended to this output stream.

        Returns
        - This output stream

        Since
        - 1.5
        """
        ...


    def append(self, csq: "CharSequence", start: int, end: int) -> "PrintStream":
        """
        Appends a subsequence of the specified character sequence to this output
        stream.
        
         An invocation of this method of the form
        `out.append(csq, start, end)` when
        `csq` is not `null`, behaves in
        exactly the same way as the invocation
        
        ````out.print(csq.subSequence(start, end).toString())````

        Arguments
        - csq: The character sequence from which a subsequence will be
                appended.  If `csq` is `null`, then characters
                will be appended as if `csq` contained the four
                characters `"null"`.
        - start: The index of the first character in the subsequence
        - end: The index of the character following the last character in the
                subsequence

        Returns
        - This output stream

        Raises
        - IndexOutOfBoundsException: If `start` or `end` are negative, `start`
                 is greater than `end`, or `end` is greater than
                 `csq.length()`

        Since
        - 1.5
        """
        ...


    def append(self, c: str) -> "PrintStream":
        """
        Appends the specified character to this output stream.
        
         An invocation of this method of the form `out.append(c)`
        behaves in exactly the same way as the invocation
        
        ````out.print(c)````

        Arguments
        - c: The 16-bit character to append

        Returns
        - This output stream

        Since
        - 1.5
        """
        ...



"""
Python module generated from Java source file org.bukkit.GrassSpecies

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import Maps
from enum import Enum
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class GrassSpecies(Enum):
    """
    Represents the different types of grass.
    """

    DEAD = (0x0)
    """
    Represents the dead looking grass.
    """
    NORMAL = (0x1)
    """
    Represents the normal grass species.
    """
    FERN_LIKE = (0x2)
    """
    Represents the fern-looking grass species.
    """


    def getData(self) -> int:
        """
        Gets the associated data value representing this species

        Returns
        - A byte containing the data value of this grass species

        Deprecated
        - Magic value
        """
        ...


    @staticmethod
    def getByData(data: int) -> "GrassSpecies":
        """
        Gets the GrassSpecies with the given data value

        Arguments
        - data: Data value to fetch

        Returns
        - The GrassSpecies representing the given value, or null
            if it doesn't exist

        Deprecated
        - Magic value
        """
        ...



"""
Python module generated from Java source file org.bukkit.configuration.file.FileConfigurationOptions

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Arrays
from java.util import Collections
from org.bukkit.configuration import MemoryConfiguration
from org.bukkit.configuration import MemoryConfigurationOptions
from org.bukkit.configuration.file import *
from typing import Any, Callable, Iterable, Tuple


class FileConfigurationOptions(MemoryConfigurationOptions):
    """
    Various settings for controlling the input and output of a FileConfiguration
    """

    def configuration(self) -> "FileConfiguration":
        ...


    def copyDefaults(self, value: bool) -> "FileConfigurationOptions":
        ...


    def pathSeparator(self, value: str) -> "FileConfigurationOptions":
        ...


    def getHeader(self) -> list[str]:
        """
        Gets the header that will be applied to the top of the saved output.
        
        This header will be commented out and applied directly at the top of
        the generated output of the FileConfiguration. It is not
        required to include a newline at the end of the header as it will
        automatically be applied, but you may include one if you wish for extra
        spacing.
        
        If no comments exist, an empty list will be returned. A null entry
        represents an empty line and an empty String represents an empty comment
        line.

        Returns
        - Unmodifiable header, every entry represents one line.
        """
        ...


    def header(self) -> str:
        """
        Returns
        - The string header.

        Deprecated
        - use getHeader() instead.
        """
        ...


    def setHeader(self, value: list[str]) -> "FileConfigurationOptions":
        """
        Sets the header that will be applied to the top of the saved output.
        
        This header will be commented out and applied directly at the top of
        the generated output of the FileConfiguration. It is not
        required to include a newline at the end of the header as it will
        automatically be applied, but you may include one if you wish for extra
        spacing.
        
        If no comments exist, an empty list will be returned. A null entry
        represents an empty line and an empty String represents an empty comment
        line.

        Arguments
        - value: New header, every entry represents one line.

        Returns
        - This object, for chaining
        """
        ...


    def header(self, value: str) -> "FileConfigurationOptions":
        """
        Arguments
        - value: The string header.

        Returns
        - This object, for chaining.

        Deprecated
        - use setHeader() instead
        """
        ...


    def getFooter(self) -> list[str]:
        """
        Gets the footer that will be applied to the bottom of the saved output.
        
        This footer will be commented out and applied directly at the bottom of
        the generated output of the FileConfiguration. It is not required
        to include a newline at the beginning of the footer as it will
        automatically be applied, but you may include one if you wish for extra
        spacing.
        
        If no comments exist, an empty list will be returned. A null entry
        represents an empty line and an empty String represents an empty comment
        line.

        Returns
        - Unmodifiable footer, every entry represents one line.
        """
        ...


    def setFooter(self, value: list[str]) -> "FileConfigurationOptions":
        """
        Sets the footer that will be applied to the bottom of the saved output.
        
        This footer will be commented out and applied directly at the bottom of
        the generated output of the FileConfiguration. It is not required
        to include a newline at the beginning of the footer as it will
        automatically be applied, but you may include one if you wish for extra
        spacing.
        
        If no comments exist, an empty list will be returned. A null entry
        represents an empty line and an empty String represents an empty comment
        line.

        Arguments
        - value: New footer, every entry represents one line.

        Returns
        - This object, for chaining
        """
        ...


    def parseComments(self) -> bool:
        """
        Gets whether or not comments should be loaded and saved.
        
        Defaults to True.

        Returns
        - Whether or not comments are parsed.
        """
        ...


    def parseComments(self, value: bool) -> "MemoryConfigurationOptions":
        """
        Sets whether or not comments should be loaded and saved.
        
        Defaults to True.

        Arguments
        - value: Whether or not comments are parsed.

        Returns
        - This object, for chaining
        """
        ...


    def copyHeader(self) -> bool:
        """
        Returns
        - Whether or not comments are parsed.

        Deprecated
        - Call .parseComments() instead.
        """
        ...


    def copyHeader(self, value: bool) -> "FileConfigurationOptions":
        """
        Arguments
        - value: Should comments be parsed.

        Returns
        - This object, for chaining

        Deprecated
        - Call .parseComments(boolean) instead.
        """
        ...



"""
Python module generated from Java source file com.google.common.base.Equivalence

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import *
from com.google.errorprone.annotations import ForOverride
from java.io import Serializable
from java.util.function import BiPredicate
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import NonNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Equivalence(BiPredicate):
    """
    A strategy for determining whether two instances are considered equivalent, and for computing
    hash codes in a manner consistent with that equivalence. Two examples of equivalences are the
    .identity() identity equivalence and the .equals "equals" equivalence.

    Author(s)
    - Gregory Kick

    Since
    - 10.0 (<a href="https://github.com/google/guava/wiki/Compatibility">mostly
        source-compatible</a> since 4.0)
    """

    def equivalent(self, a: "T", b: "T") -> bool:
        """
        Returns `True` if the given objects are considered equivalent.
        
        This method describes an *equivalence relation* on object references, meaning that for
        all references `x`, `y`, and `z` (any of which may be null):
        
        
          - `equivalent(x, x)` is True (*reflexive* property)
          - `equivalent(x, y)` and `equivalent(y, x)` each return the same result
              (*symmetric* property)
          - If `equivalent(x, y)` and `equivalent(y, z)` are both True, then `equivalent(x, z)` is also True (*transitive* property)
        
        
        Note that all calls to `equivalent(x, y)` are expected to return the same result as
        long as neither `x` nor `y` is modified.
        """
        ...


    def test(self, t: "T", u: "T") -> bool:
        """
        Since
        - 21.0

        Deprecated
        - Provided only to satisfy the BiPredicate interface; use .equivalent
            instead.
        """
        ...


    def hash(self, t: "T") -> int:
        """
        Returns a hash code for `t`.
        
        The `hash` has the following properties:
        
        
          - It is *consistent*: for any reference `x`, multiple invocations of `hash(x`} consistently return the same value provided `x` remains unchanged
              according to the definition of the equivalence. The hash need not remain consistent from
              one execution of an application to another execution of the same application.
          - It is *distributable across equivalence*: for any references `x` and `y`, if `equivalent(x, y)`, then `hash(x) == hash(y)`. It is *not*
              necessary that the hash be distributable across *inequivalence*. If `equivalence(x, y)` is False, `hash(x) == hash(y)` may still be True.
          - `hash(null)` is `0`.
        """
        ...


    def onResultOf(self, function: "Function"["F", "T"]) -> "Equivalence"["F"]:
        """
        Returns a new equivalence relation for `F` which evaluates equivalence by first applying
        `function` to the argument, then evaluating using `this`. That is, for any pair of
        non-null objects `x` and `y`, `equivalence.onResultOf(function).equivalent(a,
        b)` is True if and only if `equivalence.equivalent(function.apply(a), function.apply(b))`
        is True.
        
        For example:
        
        ````Equivalence<Person> SAME_AGE = Equivalence.equals().onResultOf(GET_PERSON_AGE);````
        
        `function` will never be invoked with a null value.
        
        Note that `function` must be consistent according to `this` equivalence
        relation. That is, invoking Function.apply multiple times for a given value must return
        equivalent results. For example, `Equivalence.identity().onResultOf(Functions.toStringFunction())` is broken because it's not
        guaranteed that Object.toString) always returns the same string instance.

        Since
        - 10.0
        """
        ...


    def wrap(self, reference: "S") -> "Wrapper"["S"]:
        """
        Returns a wrapper of `reference` that implements Wrapper.equals(Object)
        Object.equals() such that `wrap(a).equals(wrap(b))` if and only if `equivalent(a,
        b)`.
        
        The returned object is serializable if both this `Equivalence` and `reference`
        are serializable (including when `reference` is null).

        Since
        - 10.0
        """
        ...


    def pairwise(self) -> "Equivalence"[Iterable["S"]]:
        """
        Returns an equivalence over iterables based on the equivalence of their elements. More
        specifically, two iterables are considered equivalent if they both contain the same number of
        elements, and each pair of corresponding elements is equivalent according to `this`. Null
        iterables are equivalent to one another.
        
        Note that this method performs a similar function for equivalences as com.google.common.collect.Ordering.lexicographical does for orderings.
        
        The returned object is serializable if this object is serializable.

        Since
        - 10.0
        """
        ...


    def equivalentTo(self, target: "T") -> "Predicate"["T"]:
        """
        Returns a predicate that evaluates to True if and only if the input is equivalent to `target` according to this equivalence relation.

        Since
        - 10.0
        """
        ...


    @staticmethod
    def equals() -> "Equivalence"["Object"]:
        """
        Returns an equivalence that delegates to Object.equals and Object.hashCode.
        Equivalence.equivalent returns `True` if both values are null, or if neither
        value is null and Object.equals returns `True`. Equivalence.hash returns
        `0` if passed a null value.

        Since
        - 4.0 (in Equivalences)
        """
        ...


    @staticmethod
    def identity() -> "Equivalence"["Object"]:
        """
        Returns an equivalence that uses `==` to compare values and System.identityHashCode(Object) to compute the hash code. Equivalence.equivalent
        returns `True` if `a == b`, including in the case that a and b are both null.

        Since
        - 4.0 (in Equivalences)
        """
        ...


    class Wrapper(Serializable):
        """
        Wraps an object so that .equals(Object) and .hashCode() delegate to an Equivalence.
        
        For example, given an Equivalence for String strings named `equiv`
        that tests equivalence using their lengths:
        
        ````equiv.wrap("a").equals(equiv.wrap("b")) // True
        equiv.wrap("a").equals(equiv.wrap("hello")) // False````
        
        Note in particular that an equivalence wrapper is never equal to the object it wraps.
        
        ````equiv.wrap(obj).equals(obj) // always False````

        Since
        - 10.0
        """

        def get(self) -> "T":
            """
            Returns the (possibly null) reference wrapped by this instance.
            """
            ...


        def equals(self, obj: "Object") -> bool:
            """
            Returns `True` if Equivalence.equivalent(Object, Object) applied to the wrapped
            references is `True` and both wrappers use the Object.equals(Object) same
            equivalence.
            """
            ...


        def hashCode(self) -> int:
            """
            Returns the result of Equivalence.hash(Object) applied to the wrapped reference.
            """
            ...


        def toString(self) -> str:
            """
            Returns a string representation for this equivalence wrapper. The form of this string
            representation is not specified.
            """
            ...



"""
Python module generated from Java source file org.bukkit.command.ProxiedCommandSender

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class ProxiedCommandSender(CommandSender):

    def getCaller(self) -> "CommandSender":
        """
        Returns the CommandSender which triggered this proxied command

        Returns
        - the caller which triggered the command
        """
        ...


    def getCallee(self) -> "CommandSender":
        """
        Returns the CommandSender which is being used to call the command

        Returns
        - the caller which the command is being run as
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.world.TimeSkipEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import World
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.world import *
from typing import Any, Callable, Iterable, Tuple


class TimeSkipEvent(WorldEvent, Cancellable):
    """
    Called when the time skips in a world.
    
    If the event is cancelled the time will not change.
    """

    def __init__(self, world: "World", skipReason: "SkipReason", skipAmount: int):
        ...


    def getSkipReason(self) -> "SkipReason":
        """
        Gets the reason why the time has skipped.

        Returns
        - a SkipReason value detailing why the time has skipped
        """
        ...


    def getSkipAmount(self) -> int:
        """
        Gets the amount of time that was skipped.

        Returns
        - Amount of time skipped
        """
        ...


    def setSkipAmount(self, skipAmount: int) -> None:
        """
        Sets the amount of time to skip.

        Arguments
        - skipAmount: Amount of time to skip
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class SkipReason(Enum):
        """
        An enum specifying the reason the time skipped.
        """

        COMMAND = 0
        """
        When time is changed using the vanilla /time command.
        """
        CUSTOM = 1
        """
        When time is changed by a plugin.
        """
        NIGHT_SKIP = 2
        """
        When time is changed by all players sleeping in their beds and the
        night skips.
        """



"""
Python module generated from Java source file com.google.common.reflect.ImmutableTypeToInstanceMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ForwardingMap
from com.google.common.collect import ImmutableMap
from com.google.common.reflect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ImmutableTypeToInstanceMap(ForwardingMap, TypeToInstanceMap):
    """
    A type-to-instance map backed by an ImmutableMap. See also MutableTypeToInstanceMap.

    Author(s)
    - Ben Yu

    Since
    - 13.0
    """

    @staticmethod
    def of() -> "ImmutableTypeToInstanceMap"["B"]:
        """
        Returns an empty type to instance map.
        """
        ...


    @staticmethod
    def builder() -> "Builder"["B"]:
        """
        Returns a new builder.
        """
        ...


    def getInstance(self, type: "TypeToken"["T"]) -> "T":
        ...


    def getInstance(self, type: type["T"]) -> "T":
        ...


    def putInstance(self, type: "TypeToken"["T"], value: "T") -> "T":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - unsupported operation
        """
        ...


    def putInstance(self, type: type["T"], value: "T") -> "T":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - unsupported operation
        """
        ...


    def put(self, key: "TypeToken"["B"], value: "B") -> "B":
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - unsupported operation
        """
        ...


    def putAll(self, map: dict["TypeToken"["B"], "B"]) -> None:
        """
        Guaranteed to throw an exception and leave the map unmodified.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - unsupported operation
        """
        ...


    class Builder:
        """
        A builder for creating immutable type-to-instance maps. Example:
        
        ````static final ImmutableTypeToInstanceMap<Handler<?>> HANDLERS =
            ImmutableTypeToInstanceMap.<Handler<?>>builder()
                .put(new TypeToken<Handler<Foo>>() {`, new FooHandler())
                .put(new TypeToken<Handler<Bar>>() {}, new SubBarHandler())
                .build();
        }```
        
        After invoking .build() it is still possible to add more entries and build again.
        Thus each map generated by this builder will be a superset of any map generated before it.

        Since
        - 13.0
        """

        def put(self, key: type["T"], value: "T") -> "Builder"["B"]:
            """
            Associates `key` with `value` in the built map. Duplicate keys are not allowed,
            and will cause .build to fail.
            """
            ...


        def put(self, key: "TypeToken"["T"], value: "T") -> "Builder"["B"]:
            """
            Associates `key` with `value` in the built map. Duplicate keys are not allowed,
            and will cause .build to fail.
            """
            ...


        def build(self) -> "ImmutableTypeToInstanceMap"["B"]:
            """
            Returns a new immutable type-to-instance map containing the entries provided to this builder.

            Raises
            - IllegalArgumentException: if duplicate keys were added
            """
            ...



"""
Python module generated from Java source file org.bukkit.boss.BossBar

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.boss import *
from org.bukkit.entity import Player
from typing import Any, Callable, Iterable, Tuple


class BossBar:

    def getTitle(self) -> str:
        """
        Returns the title of this boss bar

        Returns
        - the title of the bar
        """
        ...


    def setTitle(self, title: str) -> None:
        """
        Sets the title of this boss bar

        Arguments
        - title: the title of the bar
        """
        ...


    def getColor(self) -> "BarColor":
        """
        Returns the color of this boss bar

        Returns
        - the color of the bar
        """
        ...


    def setColor(self, color: "BarColor") -> None:
        """
        Sets the color of this boss bar.

        Arguments
        - color: the color of the bar
        """
        ...


    def getStyle(self) -> "BarStyle":
        """
        Returns the style of this boss bar

        Returns
        - the style of the bar
        """
        ...


    def setStyle(self, style: "BarStyle") -> None:
        """
        Sets the bar style of this boss bar

        Arguments
        - style: the style of the bar
        """
        ...


    def removeFlag(self, flag: "BarFlag") -> None:
        """
        Remove an existing flag on this boss bar

        Arguments
        - flag: the existing flag to remove
        """
        ...


    def addFlag(self, flag: "BarFlag") -> None:
        """
        Add an optional flag to this boss bar

        Arguments
        - flag: an optional flag to set on the boss bar
        """
        ...


    def hasFlag(self, flag: "BarFlag") -> bool:
        """
        Returns whether this boss bar as the passed flag set

        Arguments
        - flag: the flag to check

        Returns
        - whether it has the flag
        """
        ...


    def setProgress(self, progress: float) -> None:
        """
        Sets the progress of the bar. Values should be between 0.0 (empty) and
        1.0 (full)

        Arguments
        - progress: the progress of the bar
        """
        ...


    def getProgress(self) -> float:
        """
        Returns the progress of the bar between 0.0 and 1.0

        Returns
        - the progress of the bar
        """
        ...


    def addPlayer(self, player: "Player") -> None:
        """
        Adds the player to this boss bar causing it to display on their screen.

        Arguments
        - player: the player to add
        """
        ...


    def removePlayer(self, player: "Player") -> None:
        """
        Removes the player from this boss bar causing it to be removed from their
        screen.

        Arguments
        - player: the player to remove
        """
        ...


    def removeAll(self) -> None:
        """
        Removes all players from this boss bar

        See
        - .removePlayer(Player)
        """
        ...


    def getPlayers(self) -> list["Player"]:
        """
        Returns all players viewing this boss bar

        Returns
        - a immutable list of players
        """
        ...


    def setVisible(self, visible: bool) -> None:
        """
        Set if the boss bar is displayed to attached players.

        Arguments
        - visible: visible status
        """
        ...


    def isVisible(self) -> bool:
        """
        Return if the boss bar is displayed to attached players.

        Returns
        - visible status
        """
        ...


    def show(self) -> None:
        """
        Shows the previously hidden boss bar to all attached players

        Deprecated
        - .setVisible(boolean)
        """
        ...


    def hide(self) -> None:
        """
        Hides this boss bar from all attached players

        Deprecated
        - .setVisible(boolean)
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.Chest

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from org.bukkit.inventory import Inventory
from org.bukkit.loot import Lootable
from typing import Any, Callable, Iterable, Tuple


class Chest(Container, Lootable, Lidded):
    """
    Represents a captured state of a chest.
    """

    def getBlockInventory(self) -> "Inventory":
        """
        Gets the inventory of the chest block represented by this block state.
        
        If the chest is a double chest, it returns just the portion of the
        inventory linked to the half of the chest corresponding to this block state.
        
        If the block was changed to a different type in the meantime, the
        returned inventory might no longer be valid.
        
        If this block state is not placed this will return the captured
        inventory snapshot instead.

        Returns
        - the inventory
        """
        ...



"""
Python module generated from Java source file org.bukkit.material.MaterialData

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.inventory import ItemStack
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class MaterialData(Cloneable):
    """
    Handles specific metadata for certain items or blocks

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def getData(self) -> int:
        """
        Gets the raw data in this material

        Returns
        - Raw data

        Deprecated
        - Magic value
        """
        ...


    def setData(self, data: int) -> None:
        """
        Sets the raw data of this material

        Arguments
        - data: New raw data

        Deprecated
        - Magic value
        """
        ...


    def getItemType(self) -> "Material":
        """
        Gets the Material that this MaterialData represents

        Returns
        - Material represented by this MaterialData
        """
        ...


    def toItemStack(self) -> "ItemStack":
        """
        Creates a new ItemStack based on this MaterialData

        Returns
        - New ItemStack containing a copy of this MaterialData

        Deprecated
        - this method creates an ItemStack of size 0 which is not
        generally useful. Consider .toItemStack(int).
        """
        ...


    def toItemStack(self, amount: int) -> "ItemStack":
        """
        Creates a new ItemStack based on this MaterialData

        Arguments
        - amount: The stack size of the new stack

        Returns
        - New ItemStack containing a copy of this MaterialData
        """
        ...


    def toString(self) -> str:
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def clone(self) -> "MaterialData":
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.Monitor

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.primitives import Longs
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations.concurrent import GuardedBy
from com.google.j2objc.annotations import Weak
from java.time import Duration
from java.util.concurrent import TimeUnit
from java.util.concurrent.locks import Condition
from java.util.concurrent.locks import ReentrantLock
from java.util.function import BooleanSupplier
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Monitor:
    """
    A synchronization abstraction supporting waiting on arbitrary boolean conditions.
    
    This class is intended as a replacement for ReentrantLock. Code using `Monitor`
    is less error-prone and more readable than code using `ReentrantLock`, without significant
    performance loss. `Monitor` even has the potential for performance gain by optimizing the
    evaluation and signaling of conditions. Signaling is entirely <a
    href="http://en.wikipedia.org/wiki/Monitor_(synchronization)#Implicit_signaling">implicit</a>. By
    eliminating explicit signaling, this class can guarantee that only one thread is awakened when a
    condition becomes True (no "signaling storms" due to use of java.util.concurrent.locks.Condition.signalAll Condition.signalAll) and that no signals are lost
    (no "hangs" due to incorrect use of java.util.concurrent.locks.Condition.signal
    Condition.signal).
    
    A thread is said to *occupy* a monitor if it has *entered* the monitor but not yet
    *left*. Only one thread may occupy a given monitor at any moment. A monitor is also
    reentrant, so a thread may enter a monitor any number of times, and then must leave the same
    number of times. The *enter* and *leave* operations have the same synchronization
    semantics as the built-in Java language synchronization primitives.
    
    A call to any of the *enter* methods with **void** return type should always be
    followed immediately by a *try/finally* block to ensure that the current thread leaves the
    monitor cleanly:
    
    ````monitor.enter();
    try {
      // do things while occupying the monitor` finally {
      monitor.leave();
    }
    }```
    
    A call to any of the *enter* methods with **boolean** return type should always appear
    as the condition of an *if* statement containing a *try/finally* block to ensure that
    the current thread leaves the monitor cleanly:
    
    ````if (monitor.tryEnter()) {
      try {
        // do things while occupying the monitor` finally {
        monitor.leave();
      }
    } else {
      // do other things since the monitor was not available
    }
    }```
    
    <h2>Comparison with `synchronized` and `ReentrantLock`</h2>
    
    The following examples show a simple threadsafe holder expressed using `synchronized`,
    ReentrantLock, and `Monitor`.
    
    <h3>`synchronized`</h3>
    
    This version is the fewest lines of code, largely because the synchronization mechanism used
    is built into the language and runtime. But the programmer has to remember to avoid a couple of
    common bugs: The `wait()` must be inside a `while` instead of an `if`, and
    `notifyAll()` must be used instead of `notify()` because there are two different
    logical conditions being awaited.
    
    ````public class SafeBox<V> {
      private V value;
    
      public synchronized V get() throws InterruptedException {
        while (value == null) {
          wait();`
        V result = value;
        value = null;
        notifyAll();
        return result;
      }
    
      public synchronized void set(V newValue) throws InterruptedException {
        while (value != null) {
          wait();
        }
        value = newValue;
        notifyAll();
      }
    }
    }```
    
    <h3>`ReentrantLock`</h3>
    
    This version is much more verbose than the `synchronized` version, and still suffers
    from the need for the programmer to remember to use `while` instead of `if`. However,
    one advantage is that we can introduce two separate `Condition` objects, which allows us to
    use `signal()` instead of `signalAll()`, which may be a performance benefit.
    
    ````public class SafeBox<V> {
      private V value;
      private final ReentrantLock lock = new ReentrantLock();
      private final Condition valuePresent = lock.newCondition();
      private final Condition valueAbsent = lock.newCondition();
    
      public V get() throws InterruptedException {
        lock.lock();
        try {
          while (value == null) {
            valuePresent.await();`
          V result = value;
          value = null;
          valueAbsent.signal();
          return result;
        } finally {
          lock.unlock();
        }
      }
    
      public void set(V newValue) throws InterruptedException {
        lock.lock();
        try {
          while (value != null) {
            valueAbsent.await();
          }
          value = newValue;
          valuePresent.signal();
        } finally {
          lock.unlock();
        }
      }
    }
    }```
    
    <h3>`Monitor`</h3>
    
    This version adds some verbosity around the `Guard` objects, but removes that same
    verbosity, and more, from the `get` and `set` methods. `Monitor` implements the
    same efficient signaling as we had to hand-code in the `ReentrantLock` version above.
    Finally, the programmer no longer has to hand-code the wait loop, and therefore doesn't have to
    remember to use `while` instead of `if`.
    
    ````public class SafeBox<V> {
      private V value;
      private final Monitor monitor = new Monitor();
      private final Monitor.Guard valuePresent = monitor.newGuard(() -> value != null);
      private final Monitor.Guard valueAbsent = monitor.newGuard(() -> value == null);
    
      public V get() throws InterruptedException {
        monitor.enterWhen(valuePresent);
        try {
          V result = value;
          value = null;
          return result;` finally {
          monitor.leave();
        }
      }
    
      public void set(V newValue) throws InterruptedException {
        monitor.enterWhen(valueAbsent);
        try {
          value = newValue;
        } finally {
          monitor.leave();
        }
      }
    }
    }```

    Author(s)
    - Martin Buchholz

    Since
    - 10.0
    """

    def __init__(self):
        """
        Creates a monitor with a non-fair (but fast) ordering policy. Equivalent to `Monitor(False)`.
        """
        ...


    def __init__(self, fair: bool):
        """
        Creates a monitor with the given ordering policy.

        Arguments
        - fair: whether this monitor should use a fair ordering policy rather than a non-fair (but
            fast) one
        """
        ...


    def newGuard(self, isSatisfied: "BooleanSupplier") -> "Guard":
        """
        Creates a new Guard guard for this monitor.

        Arguments
        - isSatisfied: the new guard's boolean condition (see Guard.isSatisfied
            isSatisfied())

        Since
        - 21.0
        """
        ...


    def enter(self) -> None:
        """
        Enters this monitor. Blocks indefinitely.
        """
        ...


    def enter(self, time: "Duration") -> bool:
        """
        Enters this monitor. Blocks at most the given time.

        Returns
        - whether the monitor was entered

        Since
        - 28.0
        """
        ...


    def enter(self, time: int, unit: "TimeUnit") -> bool:
        """
        Enters this monitor. Blocks at most the given time.

        Returns
        - whether the monitor was entered
        """
        ...


    def enterInterruptibly(self) -> None:
        """
        Enters this monitor. Blocks indefinitely, but may be interrupted.

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def enterInterruptibly(self, time: "Duration") -> bool:
        """
        Enters this monitor. Blocks at most the given time, and may be interrupted.

        Returns
        - whether the monitor was entered

        Raises
        - InterruptedException: if interrupted while waiting

        Since
        - 28.0
        """
        ...


    def enterInterruptibly(self, time: int, unit: "TimeUnit") -> bool:
        """
        Enters this monitor. Blocks at most the given time, and may be interrupted.

        Returns
        - whether the monitor was entered

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def tryEnter(self) -> bool:
        """
        Enters this monitor if it is possible to do so immediately. Does not block.
        
        **Note:** This method disregards the fairness setting of this monitor.

        Returns
        - whether the monitor was entered
        """
        ...


    def enterWhen(self, guard: "Guard") -> None:
        """
        Enters this monitor when the guard is satisfied. Blocks indefinitely, but may be interrupted.

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def enterWhen(self, guard: "Guard", time: "Duration") -> bool:
        """
        Enters this monitor when the guard is satisfied. Blocks at most the given time, including both
        the time to acquire the lock and the time to wait for the guard to be satisfied, and may be
        interrupted.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied

        Raises
        - InterruptedException: if interrupted while waiting

        Since
        - 28.0
        """
        ...


    def enterWhen(self, guard: "Guard", time: int, unit: "TimeUnit") -> bool:
        """
        Enters this monitor when the guard is satisfied. Blocks at most the given time, including both
        the time to acquire the lock and the time to wait for the guard to be satisfied, and may be
        interrupted.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def enterWhenUninterruptibly(self, guard: "Guard") -> None:
        """
        Enters this monitor when the guard is satisfied. Blocks indefinitely.
        """
        ...


    def enterWhenUninterruptibly(self, guard: "Guard", time: "Duration") -> bool:
        """
        Enters this monitor when the guard is satisfied. Blocks at most the given time, including both
        the time to acquire the lock and the time to wait for the guard to be satisfied.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied

        Since
        - 28.0
        """
        ...


    def enterWhenUninterruptibly(self, guard: "Guard", time: int, unit: "TimeUnit") -> bool:
        """
        Enters this monitor when the guard is satisfied. Blocks at most the given time, including both
        the time to acquire the lock and the time to wait for the guard to be satisfied.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied
        """
        ...


    def enterIf(self, guard: "Guard") -> bool:
        """
        Enters this monitor if the guard is satisfied. Blocks indefinitely acquiring the lock, but does
        not wait for the guard to be satisfied.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied
        """
        ...


    def enterIf(self, guard: "Guard", time: "Duration") -> bool:
        """
        Enters this monitor if the guard is satisfied. Blocks at most the given time acquiring the
        lock, but does not wait for the guard to be satisfied.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied

        Since
        - 28.0
        """
        ...


    def enterIf(self, guard: "Guard", time: int, unit: "TimeUnit") -> bool:
        """
        Enters this monitor if the guard is satisfied. Blocks at most the given time acquiring the
        lock, but does not wait for the guard to be satisfied.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied
        """
        ...


    def enterIfInterruptibly(self, guard: "Guard") -> bool:
        """
        Enters this monitor if the guard is satisfied. Blocks indefinitely acquiring the lock, but does
        not wait for the guard to be satisfied, and may be interrupted.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def enterIfInterruptibly(self, guard: "Guard", time: "Duration") -> bool:
        """
        Enters this monitor if the guard is satisfied. Blocks at most the given time acquiring the
        lock, but does not wait for the guard to be satisfied, and may be interrupted.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied

        Since
        - 28.0
        """
        ...


    def enterIfInterruptibly(self, guard: "Guard", time: int, unit: "TimeUnit") -> bool:
        """
        Enters this monitor if the guard is satisfied. Blocks at most the given time acquiring the
        lock, but does not wait for the guard to be satisfied, and may be interrupted.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied
        """
        ...


    def tryEnterIf(self, guard: "Guard") -> bool:
        """
        Enters this monitor if it is possible to do so immediately and the guard is satisfied. Does not
        block acquiring the lock and does not wait for the guard to be satisfied.
        
        **Note:** This method disregards the fairness setting of this monitor.

        Returns
        - whether the monitor was entered, which guarantees that the guard is now satisfied
        """
        ...


    def waitFor(self, guard: "Guard") -> None:
        """
        Waits for the guard to be satisfied. Waits indefinitely, but may be interrupted. May be called
        only by a thread currently occupying this monitor.

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def waitFor(self, guard: "Guard", time: "Duration") -> bool:
        """
        Waits for the guard to be satisfied. Waits at most the given time, and may be interrupted. May
        be called only by a thread currently occupying this monitor.

        Returns
        - whether the guard is now satisfied

        Raises
        - InterruptedException: if interrupted while waiting

        Since
        - 28.0
        """
        ...


    def waitFor(self, guard: "Guard", time: int, unit: "TimeUnit") -> bool:
        """
        Waits for the guard to be satisfied. Waits at most the given time, and may be interrupted. May
        be called only by a thread currently occupying this monitor.

        Returns
        - whether the guard is now satisfied

        Raises
        - InterruptedException: if interrupted while waiting
        """
        ...


    def waitForUninterruptibly(self, guard: "Guard") -> None:
        """
        Waits for the guard to be satisfied. Waits indefinitely. May be called only by a thread
        currently occupying this monitor.
        """
        ...


    def waitForUninterruptibly(self, guard: "Guard", time: "Duration") -> bool:
        """
        Waits for the guard to be satisfied. Waits at most the given time. May be called only by a
        thread currently occupying this monitor.

        Returns
        - whether the guard is now satisfied

        Since
        - 28.0
        """
        ...


    def waitForUninterruptibly(self, guard: "Guard", time: int, unit: "TimeUnit") -> bool:
        """
        Waits for the guard to be satisfied. Waits at most the given time. May be called only by a
        thread currently occupying this monitor.

        Returns
        - whether the guard is now satisfied
        """
        ...


    def leave(self) -> None:
        """
        Leaves this monitor. May be called only by a thread currently occupying this monitor.
        """
        ...


    def isFair(self) -> bool:
        """
        Returns whether this monitor is using a fair ordering policy.
        """
        ...


    def isOccupied(self) -> bool:
        """
        Returns whether this monitor is occupied by any thread. This method is designed for use in
        monitoring of the system state, not for synchronization control.
        """
        ...


    def isOccupiedByCurrentThread(self) -> bool:
        """
        Returns whether the current thread is occupying this monitor (has entered more times than it
        has left).
        """
        ...


    def getOccupiedDepth(self) -> int:
        """
        Returns the number of times the current thread has entered this monitor in excess of the number
        of times it has left. Returns 0 if the current thread is not occupying this monitor.
        """
        ...


    def getQueueLength(self) -> int:
        """
        Returns an estimate of the number of threads waiting to enter this monitor. The value is only
        an estimate because the number of threads may change dynamically while this method traverses
        internal data structures. This method is designed for use in monitoring of the system state,
        not for synchronization control.
        """
        ...


    def hasQueuedThreads(self) -> bool:
        """
        Returns whether any threads are waiting to enter this monitor. Note that because cancellations
        may occur at any time, a `True` return does not guarantee that any other thread will ever
        enter this monitor. This method is designed primarily for use in monitoring of the system
        state.
        """
        ...


    def hasQueuedThread(self, thread: "Thread") -> bool:
        """
        Queries whether the given thread is waiting to enter this monitor. Note that because
        cancellations may occur at any time, a `True` return does not guarantee that this thread
        will ever enter this monitor. This method is designed primarily for use in monitoring of the
        system state.
        """
        ...


    def hasWaiters(self, guard: "Guard") -> bool:
        """
        Queries whether any threads are waiting for the given guard to become satisfied. Note that
        because timeouts and interrupts may occur at any time, a `True` return does not guarantee
        that the guard becoming satisfied in the future will awaken any threads. This method is
        designed primarily for use in monitoring of the system state.
        """
        ...


    def getWaitQueueLength(self, guard: "Guard") -> int:
        """
        Returns an estimate of the number of threads waiting for the given guard to become satisfied.
        Note that because timeouts and interrupts may occur at any time, the estimate serves only as an
        upper bound on the actual number of waiters. This method is designed for use in monitoring of
        the system state, not for synchronization control.
        """
        ...


    class Guard:
        """
        A boolean condition for which a thread may wait. A `Guard` is associated with a single
        `Monitor`. The monitor may check the guard at arbitrary times from any thread occupying
        the monitor, so code should not be written to rely on how often a guard might or might not be
        checked.
        
        If a `Guard` is passed into any method of a `Monitor` other than the one it is
        associated with, an IllegalMonitorStateException is thrown.

        Since
        - 10.0
        """

        def isSatisfied(self) -> bool:
            """
            Evaluates this guard's boolean condition. This method is always called with the associated
            monitor already occupied. Implementations of this method must depend only on state protected
            by the associated monitor, and must not modify that state.
            """
            ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import Event
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerEvent(Event):
    """
    Represents a player related event
    """

    def __init__(self, who: "Player"):
        ...


    def getPlayer(self) -> "Player":
        """
        Returns the player involved in this event

        Returns
        - Player who is involved in this event
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Drowned

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Drowned(Zombie):
    """
    Drowned zombie.
    """


